from xml.dom.minidom import parse
from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Information_gathering")
        list_attacks = [
            " Useful Website",
            " Nmap     \t\t (Recommended)",
            " subfinder \t\t (Recommended)",
            " Maltego \t\t (Recommended)",
            " Dracnmap",
            " RED_HAWK",
            " Th3inspector \t (Recommended)",
            " Hping3",
            " Arping",
            "Netdiscover",
            "The Harvester",
            "Wafw00f",
            "Recon-ng",
            "Spiderfoot",
            "amass",
            "Sublist3r",
            "go back",
        ]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Useful Websites")
            os.system("clear")
            template.template("Useful Websites", "no-tools", 'This is website for information gathering', {
                " Social-Search Website": "https://www.social-searcher.com/",
                " IP2info": "https://ipinfo.io/",
                " Viewdns": "https://viewdns.info/",
                " Shodan search engine": "https://www.shodan.io/",
                " Hunter Search Engine": "https://hunter.how/",
                " AHMIA Search Engine": "https://ahmia.fi/",
                " Censys Search Engine": "https://censys.com/",
                " Wayback Machine": "https://archive.org/web/",
                " Dnsdumpster": "https://dnsdumpster.com/",
                "MXToolbox": "https://mxtoolbox.com/",
                "Lopseg": "https://www.lopseg.com.br/osint",
                "Arin whois": "https://whois.arin.net/ui/",
                "Dnschecker": "https://dnschecker.org/",
                "BGP-Toolkit": "https://bgp.he.net/",
                "Mattw.io": "https://mattw.io/",
                "Searchftps": "https://www.searchftps.net/",
                "Security Headers": "https://securityheaders.com/",
                "Robtex": "https://www.robtex.com/",
                "Builtwith": "https://builtwith.com/",
                "Intodns": "https://www.intodns.com/",
                "Searchdns": "https://searchdns.netcraft.com/",
                "Hackertarget": "https://hackertarget.com/",
                "Vulners": "https://vulners.com/",
                "cvedetails": "https://www.cvedetails.com/",
                "Zero Day initiative": "https://www.zerodayinitiative.com/",


            })

        elif option == "2":
            print("\n[+] Nmap")
            nmap()
        elif option == "3":
            print("\n[+] subfinder")
            subfinder()
        elif option == "4":
            print("\n[+] Maltego")
            maltego()
        elif option == "5":
            print("\n[+] Dracnmap")
            dracnmap()
        elif option == "6":
            print("\n[+] RED_HAWK")
            redhawk()
        elif option == "7":
            print("\n[+] Th3inspector")
            th3inspector()
        elif option == "8":
            print("\n[+] Hping3")
            hping3()
        elif option == "9":
            print("\n[+] Arping")
            arping()
        elif option == "10":
            print("\n[+] Netdiscover")
            netdiscover()
        elif option == "11":
            print("\n[+] The Harvester")
            theharvester()
        elif option == "12":
            print("\n[+] Wafw00f")
            wafw00f()
        elif option == "13":
            print("\n[+] Recon-ng")
            recon_ng()
        elif option == "14":
            print("\n[+] spiderfoot")
            spiderfoot()
        elif option == "15":
            print("\n[+] amass")
            amass()
        elif option == "16":
            print("\n[+] Sublist3r")
            sublist3r()
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    headers={'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.0.0 Safari/537.36'}
    try:
        r = requests.get(URL,headers=headers)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
    #for i in paras:
    #    print(i.text)
    # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def arping():
    os.system("clear")
    github = "arping is a tool for probing hosts in a network. Unlike the ping command, which operates at the network layer, arping operates at the data link layer and uses the Address Resolution Protocol (ARP). Using it involves sending ARP requests to a destination host and waiting for ARP replies."        
    template.template(
                "arping",
                "arping --help",
                github.strip(),
                {
                    "First resource": "https://www.networkworld.com/article/3601693/using-the-linux-arping-command-to-ping-local-systems.html",
                    "How to use this command": "https://linuxhint.com/use-arping-command-linux/",
                    "Other resources": "https://www.baeldung.com/linux/arping-command",
                },
            )
def wafw00f():
    os.system("clear")
    github = "WAFW00F is a Python tool to help you fingerprint and identify Web Application Firewall (WAF) products. It is an active reconnaissance tool as it actually connects to the web server, but it starts out with a normal HTTP response and escalates as necessary."
    template.template(
                "wafw00f",
                "wafw00f --help",
                github.strip(),
                {
                    "First resource": "https://www.briskinfosec.com/tooloftheday/toolofthedaydetail/wafw00f-tool-to-fingerprint-and-identify-web-application-firewall",
                    "Second resource": "https://null-byte.wonderhowto.com/how-to/identify-web-application-firewalls-with-wafw00f-nmap-0198145/",
                    "Third resource": "https://www.geeksforgeeks.org/identification-of-web-application-firewall-using-wafw00f-in-kali-linux/",
                    "Github resource": "https://github.com/EnableSecurity/wafw00f",
                    "Video resource": "https://www.youtube.com/watch?v=EmWXfq51pE0",
                },
            )


def nmap():
    os.system("clear")
    github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses. "
    template.template("nmap", "nmap -h", github.strip(), {"Nmap Cheat-Sheet": "https://www.stationx.net/nmap-cheat-sheet/",
                      "Official website": "https://nmap.org/ ", "Other resources": "https://linux.die.net/man/1/nmap", },)


def recon_ng():
    os.system("clear")
    github_p1 = github_getting_text(
        "https://github.com/lanmaster53/recon-ng", 'p[dir=auto]', 1)
    github_p2 = github_getting_text(
        "https://github.com/lanmaster53/recon-ng", 'p[dir=auto]', 2)
    github = github_p1+github_p2
    template.template("recon-ng", "recon-ng --help", github.strip(),
                      {"How to us Reco-ng": "https://hackertarget.com/recon-ng-tutorial/", },)


def theharvester():
    os.system("clear")
    github = "theHarvester is a simple to use, yet powerful tool designed to be used during the reconnaissance stage of a red team assessment or penetration test. It performs open source intelligence (OSINT) gathering to help determine a domain's external threat landscape. The tool gathers names, emails, IPs, subdomains, and URLs by using multiple public resources that include."
    template.template(
        "theharvester",
        "theharvester",
        github.strip(),
        {
            "The harvester CheatSheet": "https://cheatography.com/classassignment124/cheat-sheets/theharvester-cheat-sheet/",
            "How to use ": "https://thecybersecurityman.com/2018/08/01/pentest-edition-using-theharvester-to-gather-e-mail-accounts-subdomains-hosts-linkedin-users-banner-information-and-more/",
            "Information Gathering using theHarvester in Kali Linux": "https://www.hacking-tutorial.com/tips-and-trick/information-gathering-using-theharvester-in-kali-linux/#google_vignette",
            "theHarvester: a Classic Open Source Intelligence Tool": "https://securitytrails.com/blog/theharvester-tool",
            "The Harvester OSINT Reconnaissance": "https://medium.com/hacker-toolbelt/the-harvester-osint-reconnaissance-91a18a294a30", },)


def subfinder():
    os.system("clear")
    github = "subfinder is a subdomain discovery tool that returns valid subdomains for websites, using passive online sources. It has a simple, modular architecture and is optimized for speed. subfinder is built for doing one thing only - passive subdomain enumeration, and it does that very well."
    template.template(
        "subfinder",
        "subfinder",
        github.strip(),
        {
            "subfinder CheatSheet": "https://highon.coffee/blog/subfinder-cheat-sheet/",
            "How to use ": "https://blog.projectdiscovery.io/do-you-really-know-subfinder-an-in-depth-guide-to-all-features-of-subfinder-beginner-to-advanced/",
            "Uncover the Hidden Web: Discover the Power of Subfinder for Efficient Subdomain Enumeration": "https://medium.com/@cuncis/uncover-the-hidden-web-discover-the-power-of-subfinder-for-efficient-subdomain-enumeration-aad6fc05bcdd", },)


def sublist3r():
    os.system("clear")
    github = "Sublist3r is a python tool designed to enumerate subdomains of websites using OSINT. It helps penetration testers and bug hunters collect and gather subdomains for the domain they are targeting. Sublist3r enumerates subdomains using many search engines such as Google, Yahoo, Bing, Baidu and Ask. Sublist3r also enumerates subdomains using Netcraft, Virustotal, ThreatCrowd, DNSdumpster and ReverseDNS."
    template.template(
        "sublist3r",
        "sublist3r -h",
        github.strip(),
        {
            "Sublist3r Cheatsheet": "https://github.com/shreyaschavhan/pentest-tools-cheatsheet/blob/main/sublist3r.md",
            "Sublist3r – Fast Subdomains Enumeration Tool for Penetration Testers": "https://pentesttools.net/sublist3r-fast-subdomains-enumeration-tool-for-penetration-testers/", },)


def spiderfoot():
    os.system("clear")
    github = github_getting_text(
        "https://github.com/smicallef/spiderfoot", 'p[dir=auto]', 2)
    template.template(
        "spiderfoot",
        "spiderfoot --help",
        github.strip(),
        {
            "How to use Spiderfoot ": "https://www.geeksforgeeks.org/spiderfoot-a-automate-osint-framework-in-kali-linux/",
        },)


def amass():
    os.system("clear")
    github = "The OWASP Amass Project performs network mapping of attack surfaces and external asset discovery using open source information gathering and active reconnaissance techniques."
    template.template(
        "amass",
        "amass --help",
        github.strip(),
        {
            "Amass tutorial": "https://techyrick.com/amass-full-tutorial/",
            "How to use amass ": "https://blog.intigriti.com/2021/06/08/hacker-tools-amass-hunting-for-subdomains/",
            "amass user's guide": "https://github.com/owasp-amass/amass/blob/master/doc/user_guide.md", },)


def netdiscover():
    os.system("clear")
    github = "Netdiscover is a command-line oriented TCP/IP packet assembler/analyzer. It supports TCP, UDP, ICMP and RAW-IP protocols, has a traceroute mode, the ability to send files between a covered channel, and many other features."
    template.template(
        "netdiscover",
        "netdiscover -help",
        github.strip(),
        {
            "Usage in details": "https://linuxcommandlibrary.com/man/netdiscover",
            "Second resource": "https://www.cyberpratibha.com/blog/netdiscover/",
            "Video resources": "https://www.youtube.com/watch?v=yMSq7QzQcX4", },)


def maltego():
    os.system("clear")
    github = "Maltego is software used for open-source intelligence and forensics, developed by Paterva from Pretoria, South Africa. Maltego focuses on providing a library of transforms for discovery of data from open sources, and visualizing that information in a graph format, suitable for link analysis and data mining"
    template.template(
        "maltego",
        "maltego",
        github.strip(),
        {
            "Official website": "https://www.maltego.com/ ",
            "How to use it": "https://www.geeksforgeeks.org/maltego-tool-in-kali-linux/ ",
            "How to Conduct Person of Interest Investigations Using OSINT and Maltego": "https://www.maltego.com/blog/how-to-conduct-person-of-interest-investigations-using-osint-and-maltego/",
            "How to Use Maltego: A Beginner’s Guide to OSINT Analysis": "https://www.stationx.net/how-to-use-maltego/",
            "How to use Maltego": "https://medium.com/hengky-sanjaya-blog/how-to-use-maltego-f57fe77e36e2",
            "Other resources": "https://www.cybervie.com/blog/what-is-maltego-how-to-use-it-for-information-gathering/", }, )


def dracnmap():
        os.system("clear")
        github = "Dracnmap is an open source program which is using to exploit the network and gathering information with nmap help. Nmap command comes with lots of options that can make the utility more robust and difficult to follow for new users. Hence Dracnmap is designed to perform fast scaning with the utilizing script engine of nmap and nmap can perform various automatic scanning techniques with the advanced commands."
        template.template(
                "Dracnmap",
                "./dracnmap-v2.2.sh",
                github.strip(),
                {
                    "Github website": "https://github.com/Screetsec/Dracnmap",
                    "How to use": "https://www.geeksforgeeks.org/dracnmap-information-gathering-and-network-exploitation-tool/ ",
                    "Other resources": "https://www.hacking.land/2016/10/dracnmap-exploit-network-and-gathering.html?utm_source=dlvr.it&utm_medium=facebook&m=1 ",
                },
                method="github",
                github_install="git clone https://github.com/Screetsec/Dracnmap.git && cd Dracnmap && chmod +x dracnmap-v2.2.sh",
                github_check="Dracnmap",
            )
        

def redhawk():
        os.system("clear")
        github = "Red Hawk is a free and open-source tool available on GitHub. Red Hawk is used to scanning websites for information gathering and finding vulnerabilities. Red Hawk is written in PHP. It uses PHP script to do reconnaissance. Red Hawk is so powerful that it can detect content management system while scanning, it can detect IP address, it can detect webserver record, it can detect Cloudflare information, and can detect robots.txt. Red Hawk can detect WordPress, Drupal, Joomla, and Magento CMS. Red Hawk looks for error-based SQL injections, WordPress sensitive files, and WordPress version-related vulnerabilities. RedHawk uses different modules for doing all the scannings."
        template.template(
                "RED_HAWK",
                "php rhawk.php",
                github.strip(),
                {
                    "How to use": "https://systemweakness.com/red-hawk-an-information-gathering-tool-d12a66da7c63 ",
                    "Other resources": "https://www.geeksforgeeks.org/red-hawk-information-gathering-and-vulnerability-scanning-tool-in-kali-linux/ ",
                },
                method="github",
                github_install="git clone https://github.com/Tuhinshubhra/RED_HAWK.git",
                github_check="RED_HAWK",
            )

def th3inspector():
        os.system("clear")
        github = "Th3inspector is an open source program which is using to exploit the network and gathering information with nmap help. Nmap command comes with lots of options that can make the utility more robust and difficult to follow for new users. Hence Dracnmap is designed to perform fast scaning with the utilizing script engine of nmap and nmap can perform various automatic scanning techniques with the advanced commands."
        template.template(
                "Th3inspector",
                "perl Th3inspector.pl",
                github.strip(),
                {
                    "github Website": "https://github.com/Moham3dRiahi/Th3inspector ",
                    "First resource": "https://www.geeksforgeeks.org/th3inspector-osint-tool-for-reconnaissance/ ",
                    "Second resource": "https://pentesttools.net/th3inspector-tool-for-information-gathering/",
                },
                method="github",
                github_install="git clone https://github.com/Moham3dRiahi/Th3inspector.git",
                github_check="Th3inspector",
            )

def hping3():
        os.system("clear")
        github = "hping is a command-line oriented TCP/IP packet assembler/analyzer. It supports TCP, UDP, ICMP and RAW-IP protocols, has a traceroute mode, the ability to send files between a covered channel, and many other features."
        template.template(
                "hping3",
                "hping3 -h",
                github.strip(),
                {
                    "First resource": "https://linux.die.net/man/8/hping3",
                    "Hping Tips and Tricks": "https://iphelix.medium.com/hping-tips-and-tricks-85698751179f",
                    "Hping3: Full tutorial from noob to pro": "https://techyrick.com/hping3-full-tutorial-for-dummies-to-pro/",
                },
            )


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,Exploitation_Tools
import os
import requests
from bs4 import BeautifulSoup

# main function


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Post Exploitation")
        list_attacks = [" Metasploit-Framework\t\t(Recommended)", " LinPeas", " LinEnum", " Sudo killer\t\t\t(Recommended)", " Beroot", " Linux Exploit Suggester 2", " LSE (Linux Smart Enumeration) ",
                        " PSPY","Linux Private-i", "Shellter", "UPX (Ultimate Packer for Executable)", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Metasploit-Framework")
            Exploitation_Tools.metasploit()    
        elif option == "2":
            print("\n[+] LinPeas")
            linpeas()        
        elif option == "3":
            print("\n[+] LinEnum")
            linenum()       
        elif option == "4":
            print("\n[+] Sudo killer")
            sudokiller()    
        elif option == "5":
            print("\n[+] Beroot")
            beroot()        
        elif option == "6":
            print("\n[+] Linux Exploit Suggester 2")
            linux_exploit_suggester2()        
        elif option == "7":
            print("\n[+] LSE (Linux Smart Enumeration)")
            linux_smart_enumeration()        
        elif option == "8":
            print("\n[+] PSPY")
            pspy()       
        elif option == "9":
            print("\n[+] Linux Private-i")
            linux_private_i()        
        elif option == "10":
            print("\n[+] Shellter")
            shelter()        
        elif option == "11":
            print("\n[+] UPX (Ultimate Packer for Executable)")
            upx()        
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
         return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


def upx():
    os.system("clear")
    github = "UPX is a free, portable, extendable, high-performance executable packer for several different executable formats. It can be used to compress and obfuscate executable files to make them smaller and more difficult to reverse engineer. UPX supports a wide range of file formats, including Windows PE, Linux ELF, and more. UPX is available for a variety of platforms, including Windows, Linux, and macOS. The UPX compression algorithm is designed to compress the code section of an executable file, while leaving the data section uncompressed. This allows the compressed code to be executed directly from memory without the need to decompress it first. UPX is open-source and actively maintained, with updates and bug fixes released regularly."
    template.template("UPX (Ultimate Packer for Executable)", "chmod u+x upx && ./upx", github.strip(), {"UPX README": "https://github.com/upx/upx#readme", "UPX Video - 1 ": "https://www.youtube.com/watch?v=upTXpDhI0ww"}, method="github",
                              github_install="wget  https://github.com/upx/upx/releases/download/v4.0.1/upx-4.0.1-i386_linux.tar.xz  && tar -xf upx-4.0.1-i386_linux.tar.xz && rm upx-4.0.1-i386_linux.tar.xz", github_check="upx-4.0.1-i386_linux")
        
def shelter():
    os.system("clear")
    github = "Shellter is a dynamic shellcode injection tool aka dynamic PE infector. It can be used in order to inject shellcode into native Windows applications (currently 32-bit apps only). The shellcode can be something yours or something generated through a framework, such as Metasploit. Shellter takes advantage of the original structure of the PE file and doesn't apply any  modification such as changing memory access permissions in sections (unless the user wants to), adding an extra section with RWE access, and whatever would look dodgy under an AV scan. Shellter is not just an EPO infector that tries to find a location to insert an instruction to redirect execution to the payload. Unlike any other infector, Shellter’s advanced infection engine never transfers the execution flow to a code cave or to an added section in the infected PE file. Shellter uses a unique dynamic approach which is based on the execution flow of the target application. This means that no static/predefined locations are used for shellcode injection. Shellter will launch and trace the target, while at the same time will log the execution flow of the application."
    template.template("shellter", "shellter", github.strip(), {"Introduction to Shellter": "https://github.com/ParrotSec/shellter#readme", "Tool documentation for Shellter on Kali Linux": "https://www.kali.org/tools/shellter/#tool-documentation", "Anti-virus Bypass with Shellter 5.1 on Kali Linux": "https://cyberarms.wordpress.com/2015/10/04/anti-virus-bypass-with-shellter-5-1-on-kali-linux/",
                              "Shellter: A Shellcode Injecting Tool": "https://www.hackingarticles.in/shellter-a-shellcode-injecting-tool/", "Shellter - The Ultimate Tool for AV Evasion": "https://metalkey.github.io/shellter---the-ultimate-tool-for-av-evasion.html", "Hack like a Pro: Evade AV Software with Shellter": "https://null-byte.wonderhowto.com/how-to/hack-like-pro-evade-av-software-with-shellter-0168504/"})
        
def linux_private_i():
    os.system("clear")
    github = "A Linux Enumeration & Privilege Escalation tool that automates the basic enumeration steps and displays the results in an easily readable format. The script comes loaded with a variety of 4 Options to choose from. Using Bash, execute private-i.sh on the local low privileged user. Select an option, execute & watch the show. Each mode uses common Linux binaries to enumerate the local system (find, grep, ps, etc). If you have a non-bash shell such as sh, use Noir-Private-i. Either script will not write or auto-exploit in any way"
    template.template("linux-private-i", "./private-i.sh", github.strip(), {"Documentation": "https://github.com/rtcrowley/linux-private-i/blob/master/README.md", "HackingArticles-linux-privilege-escalation-automated-script":
                              "https://www.hackingarticles.in/linux-privilege-escalation-automated-script"}, method="github", github_install="git clone https://github.com/rtcrowley/linux-private-i.git && cd linux-private-i && chmod +x *", github_check="linux-private-i")
        
def pspy():
    os.system("clear")
    github = "pspy is a command line tool designed to snoop on processes without need for root permissions. It allows you to see commands run by other users, cron jobs, etc. as they execute. Great for enumeration of Linux systems in CTFs. Also great to demonstrate your colleagues why passing secrets as arguments on the command line is a bad idea.This tool gathers the info from procfs scans. Inotify watchers placed on selected parts of the file system trigger these scans to catch short-lived processes."
    version = github_getting_text("https://github.com/DominicBreuker/pspy/releases/",
                                          'div[class="css-truncate css-truncate-target"]', 0).strip()
    template.template("pspy64", "chmod u+x pspy64 && ./pspy64", github.strip(), {"Using-PSPY-To-Monitor-Linux-Processes": "https://infinitelogins.com/2020/09/04/using-ps-py-to-monitor-linux-processes", "Cyberkendra Pspy-Tool-Monitor-Linux-Processes": "https://tools.cyberkendra.com/2020/04/pspy-tool-monitor-linux-processes.html", "How-To-Enumerate-Services-In-Use-With-PSPY": "https://vk9-sec.com/how-to-enumerate-services-in-use-with-pspy",
                              "TryHackMe-ConvertMyVideo Writeup": "https://sparshjazz.medium.com/tryhackme-convertmyvideo-writeup-56b6c8217001", "SecurityOnline PSPY": "https://securityonline.info/pspy"}, method="github", github_install=f"wget  https://github.com/DominicBreuker/pspy/releases/download/{version}/pspy64 && mkdir PSPY && mv pspy64 PSPY", github_check="PSPY")
        
def linux_smart_enumeration():
    os.system("clear")
    github = "Linux Smart Enumeration (LSE) is a script written by Diego Treitos that automates the enumeration process for Linux systems. It is designed to run quickly and efficiently, and to provide detailed information about the system, including users, groups, permissions, network configuration, and more. LSE is intended to be used by penetration testers and security professionals to gather information about a target system during the reconnaissance phase of an engagement."
    template.template("linux-smart-enumeration", "chmod u+x lse.sh && ./lse.sh", github.strip(), {"Documentation (linux-smart-enumeration)": "https://github.com/diego-treitos/linux-smart-enumeration/blob/master/README.md", "Use-Linux-Smart-Enumeration-Discover-Paths-Privesc":
                              "https://null-byte.wonderhowto.com/how-to/use-linux-smart-enumeration-discover-paths-privesc-0330807", "Hakin9 linux-smart-enumeration": "https://hakin9.org/linux-smart-enumeration"}, method="github", github_install="git clone https://github.com/diego-treitos/linux-smart-enumeration.git", github_check="linux-smart-enumeration")
        
def linux_exploit_suggester2():
    os.system("clear")
    github = "Linux Exploit Suggester 2 (LES 2) is a tool that can be used to identify potential vulnerabilities and exploits that can be used to compromise a Linux system. It works by analyzing the running kernel version and system information, and then comparing it to a local database of known vulnerabilities and exploits. LES 2 can also be used to determine whether a patch has been applied to a specific vulnerability, making it useful for identifying systems that are still vulnerable to known exploits. The tool is open-source and can be easily installed on a Linux system. It supports a wide range of Linux distributions, including Ubuntu, Debian, Fedora, Arch Linux and more. LES 2 is a command-line tool and requires Python to run.It's a useful tool for penetration testers and system administrators to identify and prioritize vulnerabilities on their systems."
    template.template("linux-exploit-suggester-2", "chmod u+x linux-exploit-suggester-2.pl && ./linux-exploit-suggester-2.pl", github.strip(), {"Kali Tools (linux-exploit-suggester)": "https://www.kali.org/tools/linux-exploit-suggester/", "Find-Exploits-Get-Root-With-Linux-Exploit-Suggester": "https://null-byte.wonderhowto.com/how-to/find-exploits-get-root-with-linux-exploit-suggester-0206005", "Pentest-Monkey Linux-Exploit-Suggester": "https://pentestmonkey.net/tools/audit/exploit-suggester",
                              "Linux-Exploit-Suggester-A-Kali-Linux-Tool-To-Find-The-Linux-Os-Kernel-Exploits": "https://gbhackers.com/linux-exploit-suggester-a-kali-linux-tool-to-find-the-linux-os-kernel-exploits", "Securityonline Linux-Exploit Suggester": "https://securityonline.info/linux-exploit-suggester-2"}, method="github", github_install="git clone https://github.com/jondonas/linux-exploit-suggester-2.git", github_check="linux-exploit-suggester-2")
        
def beroot():
    os.system("clear")
    github_text_0 = github_getting_text(
                "https://github.com/AlessandroZ/BeRoot", 'p[dir=auto]', 0)
    github_text_1 = github_getting_text(
                "https://github.com/AlessandroZ/BeRoot", 'p[dir=auto]', 1)
    github = github_text_0.strip().replace("\n", "").replace("\t", "") + github_text_1.strip().replace("\n", "").replace("\t", "")
    template.template("BeRoot", "cd Linux && chmod u+x * && ./beroot.py", github.strip(), {"BeRoot-Linux-Privilege-Escalation": "https://www.kitploit.com/2018/06/beroot-for-linux-privilege-escalation.html?m=0", "BeRoot-A-Post-Exploitation-Privilege-Escalation-Tool":
                              "https://blog.hackersonlineclub.com/2018/07/beroot-post-exploitation-tool-to-check.html", "BeRoot-Windows-Privilege-Escalation": "https://sevenlayers.com/index.php/273-windows-privilege-escalation"}, method="github", github_install="git clone https://github.com/AlessandroZ/BeRoot.git", github_check="BeRoot")
        
def sudokiller():
    os.system("clear")
    github_text_6 = github_getting_text(
                "https://github.com/TH3xACE/SUDO_KILLER", 'p[dir=auto]', 6)
    github_text_7 = github_getting_text(
                "https://github.com/TH3xACE/SUDO_KILLER", 'p[dir=auto]', 7)
    github = github_text_6 + github_text_7
    template.template("Sudo Killer", "chmod u+x * && ./SUDO_KILLERv3.sh", github.strip(), {"SUDO_KILLER-Demos": "https://github.com/TH3xACE/SUDO_KILLER#demos", "Sudo-Killer Information": "https://www.kitploit.com/2020/02/sudokiller-tool-to-identify-and-exploit.html",
                              "Sudo-Killer-Identify-Abuse-Sudo-Misconfigurations": "https://null-byte.wonderhowto.com/how-to/use-sudo-killer-identify-abuse-sudo-misconfigurations-0202594"}, method="github", github_install="git clone https://github.com/TH3xACE/SUDO_KILLER.git", github_check="SUDO_KILLER")
        
def linenum():
    os.system("clear")
    github = "LinEnum is a Linux enumeration script that can be used to enumerate information from a Linux system. It is designed to be run locally on a Linux system and will attempt to enumerate common files, folders, users, groups, services, configurations, and permissions. It can also be used to look for certain security vulnerabilities such as local privilege escalation. LinEnum can be run from the command line or can be automated using a script. The output of the script can be saved as a text file for later analysis."
    template.template("LinEnum", "chmod +x LinEnum.sh && ./LinEnum.sh -h", github.strip(), {"Use-LinEnum-Identify-Potential-Privilege-Escalation-Vectors": "https://null-byte.wonderhowto.com/how-to/use-linenum-identify-potential-privilege-escalation-vectors-0197225/", "Linux-Privilege-Escalation-With-LinEnum": "https://trevorxcohen.medium.com/linux-privilege-escalation-with-linenum-75d20a3b59f6", "LinEnum-Linux-Enumeration-Privilege-Escalation-Tool": "https://www.darknet.org.uk/2014/11/linenum-linux-enumeration-privilege-escalation-tool",
                              "Linux-Privilege-Escalation-Quick-And-Dirty": "https://reboare.gitbooks.io/booj-security/content/general-linux/privilege-escalation.html", "Linux Enumeration And Privilege Escalation – LinEnum": "https://vulners.com/n0where/N0WHERE:24819"}, method="github", github_install="curl -s https://raw.githubusercontent.com/rebootuser/LinEnum/master/LinEnum.sh -o LinEnum.sh && mkdir LinEnum && mv LinEnum.sh LinEnum", github_check="LinEnum")
        
def linpeas():
    os.system("clear")
    github = "LinPeas is a script that automates the process of gathering information about a Linux system, similar to Windows' PowerShell script PEAS. This script can help identify potential vulnerabilities and misconfigurations on a Linux system, as well as provide information about system and network configuration. It can be useful for penetration testing, security assessments, and incident response. The script can be executed with arguments to specify which information to gather, or without arguments to gather all available information"
    template.template("linPEAS", "chmod +x linpeas.sh && ./linpeas.sh -h", github.strip(), {"LinPeas Blog": "https://blog.cyberethical.me/linpeas", "Linux-Privilege-Escalation": "https://delinea.com/blog/linux-privilege-escalation", "Linux Privilege Escalation: Quick and Dirty": " https://github.com/carlospolop/PEASS-ng/tree/master/linPEAS", "Outrunsec LinPeas":
                              "https://outrunsec.com/tag/linpeas/", "Linux-Privilege-Escalation-Suid-Binaries": "https://steflan-security.com/linux-privilege-escalation-suid-binaries"}, method="github", github_install="wget https://github.com/carlospolop/PEASS-ng/releases/latest/download/linpeas.sh  && mkdir LinPeas && mv linpeas.sh LinPeas", github_check="LinPeas")
        

if __name__ == '__main__':
    main()



from cyberonix.main.tools import template
import os
def main():
    print("\n[+] FrameWork")
    os.system("clear")
    template.template("Framework","no-tools","Writeups",
                    {
                            "OSINT Framework":"https://osintframework.com/",
                            "MITRE Framework":"https://attack.mitre.org/",
                    })



if __name__=='__main__':
    main()




from cyberonix.main.tools import banner,colors,template,Sniffing_and_Spoofing
import os
from cyberonix.main.tools import writeup
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Cryptography Failure")
        list_root_attacks=["Tool","Writeups","go back"]
        for i in range(len(list_root_attacks)):
            print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks=["Bettercap","Ettercap (Graphical of bettercap)","sslyze","O-Saft","sslscan","go back"]
                for i in range(len(list_attacks)):
                    print(colors.options,f"{i+1}) {list_attacks[i]}".title(),colors.reset)
                try:
                    option2 = input(f"\n {colors.select}Select An Option ->  {colors.reset}")
                except KeyboardInterrupt:
                    return
                if option2=="1":
                    print(f"\n[+] Bettercap")
                    Sniffing_and_Spoofing.bettercap()
                elif option2=="2":
                    print("\n[+] Ettercap (Graphical of bettercap)")
                    ettercap()            
                elif option2=="3":
                    print("\n[+] sslyze")
                    sslyze()            
                elif option2=="4":
                    print(f"\n[+] O-Saft")
                    o_saft()                
                elif option2=="5":
                    print(f"\n[+] sslscan")
                    sslscan()
                else:
                    break
        elif option == "2":
            os.system("clear")
            writeup.writeup({"SSLLabs (Website)":"https://www.ssllabs.com/ssltest/","A02-2021 Cryptographic Failures by OWASP":"https://owasp.org/Top10/A02_2021-Cryptographic_Failures/","Cryptographic Failures by Synack":"https://www.synack.com/blog/preventing-cryptographic-failures-the-no-2-vulnerability-in-the-owasp-top-10/","Cryptographic Failures by MYF5":"https://my.f5.com/manage/s/article/K00174750","Cryptographic Failures by Qawerk":"https://qawerk.com/blog/cryptographic-failure/"},"Cryptography Failure Write-UPS")
        else:
            return

def sslscan():
    os.system("clear")
    github = "SSLScan is a free tool that helps in identifying SSL/TLS vulnerabilities and misconfigurations in SSL/TLS enabled servers. It scans and evaluates the SSL/TLS connection on the target server and provides a detailed report of any weak ciphers, protocols or configurations that can be exploited by attackers. SSLScan is commonly used by security professionals and penetration testers to assess the security posture of an organization's SSL/TLS infrastructure. It is available for Windows, Linux, and MacOS platforms."
    template.template("sslscan","sslscan",github.strip(),{"SSLSCAN by Oreilly": "https://www.oreilly.com/library/view/web-penetration-testing/9781788623377/285990a3-9992-40b0-ac36-69adc6fb47ce.xhtml"})
                
def o_saft():
    os.system("clear")
    github="O-Saft is an open-source tool designed for analyzing and detecting the security configuration issues in web applications. It mainly focuses on the security headers and their misconfigurations, which might lead to security vulnerabilities. The tool scans the website and generates a report that contains information about the misconfigured security headers, their impact, and how to fix them. O-Saft helps the developers to ensure the security of their web applications and protect them from various cyber threats."
    template.template("o-saft","o-saft --help",github.strip(),{"O-Soft by OWASP": "https://owasp.org/www-project-o-saft/","O-Soft by Kali": "https://www.kali.org/tools/o-saft/"})
                
def sslyze():
    os.system("clear")
    github="SSLyze is a Python-based command-line tool that helps in evaluating the SSL/TLS security posture of a given target. It allows users to analyze SSL/TLS configuration on a server and detect various security issues like weak ciphers, certificate issues, and misconfigurations. SSLyze is useful for system administrators, security professionals, and developers to test and evaluate the security of SSL/TLS implementations. It is an open-source tool and is available for free under the GPL v3 license."
    template.template("sslyze","sslyze -h",github.strip(),{"SSLyze by GeeksforGeeks": "https://www.geeksforgeeks.org/sslyze-fast-and-powerful-ssl-tls-scanning-tool/","SSLyze by Securecodebox": "https://www.securecodebox.io/docs/scanners/sslyze/"},method="pip")
                
def ettercap():
    os.system("clear")
    github="Ettercap is a popular open-source GUI network security tool that is used for monitoring and analyzing network traffic in real-time. It can be used to perform various types of attacks such as ARP spoofing, IP and MAC address spoofing, session hijacking, DNS spoofing, etc. Ettercap is commonly used by network administrators and security experts to test the security of their own networks and to identify potential vulnerabilities. It supports various protocols like TCP, UDP, ICMP, and can also decode SSL traffic. Ettercap can be used on various operating systems including Windows, Linux, and Mac OS X."
    template.template("ettercap-graphical","ettercap -G",github.strip(),{"SSLStriping Using Ettercap by NULL-BYTE": 'https://null-byte.wonderhowto.com/forum/struggling-perform-mitm-attack-using-ettercap-and-sslstrip-0165933/','HSTS Hijacing': "https://github.com/bettercap/caplets/blob/master/hstshijack/README.md",})
                
if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Digital Forensic Tools")
        list_attacks=["Autopsy","Binwalk","Hashdeep","Bulk Extractor","Go Back"]
        for i in range(len(list_attacks)):
                print(colors.options,f"{i+1}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "1":
            print("\n[+] Autopsy")
            autopsy()        
        elif option == "2":
            print("\n[+] Binwalk")
            binwalk()            
        elif option == "3":
            print("\n[+] Hashdeep")
            hashdeep()        
        elif option == "4":
            print("\n[+] Bulk Extractor")
            bulk_extractor()        
        else:
            return

def autopsy():
    os.system("clear")
    github = "The Autopsy Forensic Browser is a graphical interface to the command line digital forensic analysis tools in The Sleuth Kit. Together, The Sleuth Kit and Autopsy provide many of the same features as commercial digital forensics tools for the analysis of Windows and UNIX file systems (NTFS, FAT, FFS, EXT2FS, and EXT3FS)."
    template.template(
                "autopsy",
                "autopsy",
                github.strip(),
                {"Forensic Autopsy":"https://www.ncbi.nlm.nih.gov/books/NBK539901/",
                "Autopsy – Cyber Forensic Browser in Kali Linux": "https://www.geeksforgeeks.org/autopsy-cyber-forensic-browser-in-kali-linux/",
                 "TryHackMe Autopsy Write-Up":"https://medium.com/@laupeiip/tryhackme-autopsy-write-up-98fad3e98e8b",
                },
            )
def bulk_extractor():
    os.system("clear")
    github = """bulk_extractor is a C++ program that scans a disk image, a file, or a directory of files and extracts useful information without parsing the file system or file system structures. The results are stored in feature files that can be easily inspected, parsed, or processed with automated tools. bulk_extractor also creates histograms of features that it finds, as features that are more common tend to be more important."""
    template.template(
                "bulk-extractor",
                "bulk_extractor",
                github.strip(),
                {"cheat sheet": "https://www.kalilinux.in/2020/01/bulk-extractor-kali-linux-forensics.html",
                 "Extracting Forensic Data from a Device Using Bulk Extractor":"https://www.researchgate.net/publication/350502325_Extracting_Forensic_Data_from_a_Device_Using_Bulk_Extractor",
                 "USER MANUAL":"https://digitalcorpora.s3.amazonaws.com/downloads/bulk_extractor/BEUsersManual.pdf",
                 "Using Bulk_extractor":"https://www.oreilly.com/library/view/digital-forensics-with/9781788625005/576053c4-24b9-42d5-a822-d44dbe05647c.xhtml",
                 },
            )
    

def binwalk():
    os.system("clear")
    github = "Binwalk is a popular open-source tool used in digital forensics and cybersecurity for analyzing, extracting, and identifying various file types embedded within firmware images and binary files. It is particularly useful for examining firmware images such as those found in embedded devices like routers, IoT devices, and other hardware."
    template.template(
                "binwalk",
                "binwalk",
                github.strip(),
                {"cheat sheet": "https://gbhackers.com/analyzing-embedded-files-and-executable-code-with-frimware-images-binwalk/",
                 "Analysing and extracting firmware using Binwalk":"https://fr3ak-hacks.medium.com/analysing-and-extracting-firmware-using-binwalk-982012281ff6",
                 "Reverse engineering my router's firmware with binwalk":"https://sergioprado.blog/reverse-engineering-router-firmware-with-binwalk/",
                 
                 },
            )
        
def hashdeep():
    os.system("clear")
    github = "hashdeep is a set of tools to compute MD5, SHA1, SHA256, tiger and whirlpool hashsums of arbitrary number of files recursively."
    template.template(
                "hashdeep",
                "hashdeep -h",
                github.strip(),
                {"cheat sheet":"https://www.codecnetworks.com/blog/hashdeep-chfi-forensics-tool/",
                 "Hashdeep -File Integrity Checker ( CHFI Forensics tool )":"https://www.codecnetworks.com/blog/hashdeep-chfi-forensics-tool/",
                 "Verify File Integrity with Hashdeep":"https://geekthis.net/post/file-integrity-with-hashdeep/",
                 },
            )
if __name__=='__main__':
    main()



from cyberonix.main.tools import banner, colors, template,Session_Management,information_gathering,WEB_Application_Analysis,Vulnerability_Analysis,Exploitation_Tools,Password_Hacking
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Authorization")
        list_attacks = ["Tools", "Writeups", "Burp Extensions", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    " Burp Suite",
                    " Wireshark",
                    " OWASP ZAP",
                    " Nessus",
                    " Hydra",
                    " BeEF",
                    " Sqlmap",
                    " Metasploit",
                    " Nmap",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if option == "1":
                    os.system("clear")
                    WEB_Application_Analysis.burp_suite()
                elif option == "2":
                    os.system("clear")
                    Vulnerability_Analysis.wireshark()
                elif option == "3":
                    os.system("clear")
                    WEB_Application_Analysis.owasp_zap()
                elif option == "4":
                    os.system("clear")
                    WEB_Application_Analysis.nessus()
                elif option == "5":
                    os.system("clear")
                    Password_Hacking.hydra()
                elif option == "6":
                    os.system("clear")
                    Exploitation_Tools.beef()
                elif option == "7":
                    os.system("clear")
                    Exploitation_Tools.sqlmap()
                elif option == "8":
                    os.system("clear")
                    Exploitation_Tools.metasploit()
                elif option == "9":
                    os.system("clear")
                    information_gathering.nmap()
                elif option == "10":
                    os.system("clear")
                    Session_Management.ptf()
                else:
                    break
        elif option == "2":
            print("\n[+] Write-UPS")
            os.system("clear")
            template.template("Writeup","no-tools","Writeups",
                {
                    " Securing Applications with Better User Authorization": "https://medium.com/capital-one-tech/securing-applications-with-better-user-authorization-625ec07a7001",
                    " Access Control": "https://portswigger.net/web-security/access-control",
                    " Web Security: Authentication & Authorization": "https://coderstower.com/2020/03/23/web-security-authentication-authorization/",
                    " Authentication & Authorization in Web Apps": "https://blog.jscrambler.com/authentication-authorization-in-web-apps",
                    " Session IDs - OWASP": "https://www.cgisecurity.com/lib/SessionIDs.pdf",
                    " JWT Authorization in Web Applications": "https://concisesoftware.com/blog/jwt-authorization-in-web-applications/",
                    " Insecure Authorization": "https://www.appsealing.com/insecure-authorization/",
                    " OAuth Vulnerabilities: Implementing Secure Authorization in Your Web Application": "https://medium.com/swlh/oauth-vulnerabilities-implementing-secure-authorization-in-your-web-application-3b9517b34798",
                    " OWASP Top 10 - Broken Access Control": "https://owasp.org/Top10/A01_2021-Broken_Access_Control/",
                    "Broken Authorization Vulnerability": "https://knowledge-base.secureflag.com/vulnerabilities/broken_authorization/broken_authorization_vulnerability.html",
                    "OWASP Web Security Testing Guide - Authorization Testing": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/05-Authorization_Testing/README",
                    "Web Authentication & Authorization": "https://www.slideshare.net/alex_pasaila/web-authentication-authorization-10930449",
                    "Web Security - Authorization": "https://www3.rocketsoftware.com/rocketd3/support/documentation/Uniface/10/uniface/webApps/webSecurity/webSecurity_Authorization.htm",
                    "Authorization Best Practices": "https://goteleport.com/blog/authorization-best-practices/",
                    "Secure Your Web Application with Spring Security - Identify How to Secure Access to an App Using Authentication and Authorization": "https://openclassrooms.com/en/courses/5683681-secure-your-web-application-with-spring-security/6695816-identify-how-to-secure-access-to-an-app-using-authentication-and-authorization",
                    "Preventing Broken Access Control": "https://crashtest-security.com/broken-access-control-prevention/",
                    "Preventing Broken Access Control - The No. 1 Vulnerability in the OWASP Top 10 2021": "https://www.synack.com/blog/preventing-broken-access-control-the-no-1-vulnerability-in-the-owasp-top-10-2021/",
                    "A Step-by-Step Guide to Broken Access Control Attacks": "https://www.polar.security/post/a-step-by-step-guide-to-broken-access-control-attacks",
                    "Broken-Access-Control - packetlabs": "https://www.packetlabs.net/posts/broken-access-control",
                    "Broken-Access-Control - qawerk": "https://qawerk.com/blog/broken-access-control/",
                    "Testing for Broken Authentication in Web Apps": "https://www.section.io/engineering-education/testing-for-broken-authentication-in-web-apps/",
                    "Broken-Access-Control (javascript) - Snyk": "https://learn.snyk.io/lessons/broken-access-control/javascript/",
                    "JSON Web Tokens Decoder - JWT.IO": "https://jwt.io/",
                    "Authorization Code Grant - Zine": "https://pbs.twimg.com/media/Et2T02KVcAEONV0?format=jpg&name=large",
                    "OWASP API1: 2019 – Broken Object Level Authorization": "https://securityboulevard.com/2023/02/owasp-api1-2019-broken-object-level-authorization/",
                    "BOLA: 3-Digit Bounty from Topcoder": "https://infosecwriteups.com/what-is-bola-3-digit-bounty-from-topcoder-a25e7fae0d64",
                    "Broken Function Level Authorization (API Security) 0x2": "https://infosecwriteups.com/broken-function-level-authorization-api-security-0x2-23a6d7c1aa46",
                    "A Deep Dive on the Most Critical API Vulnerability: BOLA": "https://inonst.medium.com/a-deep-dive-on-the-most-critical-api-vulnerability-bola-1342224ec3f2",
                    "Broken Object Level Authorization (BOLA) - NordiAPIs": "https://nordicapis.com/what-is-broken-object-level-authorization-and-how-to-fix-it/",
                    "Broken Function Level Authorization Leads to Disclosing PII Information of All Company Users": "https://webresearcher007.medium.com/broken-function-level-authorization-leads-to-disclosing-pii-information-of-all-company-users-35aee60b287b",
                },
                "Authorization Write-UPS",
            )

        elif option == "3":
            print("\n[+] Burp Extensions")
            os.system("clear")
            banner.main()
            template.template("Burp Extensions","no-tools","Writeups",
                {
                    " Portswigger - Auth Analyzer": "https://portswigger.net/bappstore/7db49799266c4f85866f54d9eab82c89",
                    " Github - Auth Analyzer": "https://github.com/simioni87/auth_analyzer",
                    " Portswigger - AutoRepeater": "https://portswigger.net/bappstore/f89f2837c22c4ab4b772f31522647ed8",
                    " Github - AutoRepeater": "https://github.com/nccgroup/AutoRepeater",
                    " Github - Burp-SessionAuthTool": "https://github.com/thomaspatzke/Burp-SessionAuthTool",
                    " Github - BurpAuthzPlugin": "https://github.com/wuntee/BurpAuthzPlugin",
                    " Github - Burp-uuid": "https://github.com/silentsignal/burp-uuid",
                    " Github - Autorize": "https://github.com/Quitten/Autorize",
                    " Github - AuthMatrix": "https://github.com/SecurityInnovation/AuthMatrix",
                    "Github - Burplay": "https://github.com/SpiderLabs/burplay",
                    "Github - Param-Miner": "https://github.com/PortSwigger/param-miner",
                    "Portswigger - SAML Raider": "https://portswigger.net/bappstore/c61cfa893bb14db4b01775554f7b802e",
                    "Portswigger - Authz": "https://portswigger.net/bappstore/4316cc18ac5f434884b2089831c7d19e",
                },
                "Authorization Burp Extensions",
            )

        else:
            return


if __name__ == "__main__":
    main()



from bs4 import BeautifulSoup
from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Wireless Hacking")
        list_attacks = ["Kismet\t\t(Recommended)", "Wifite", "Fern Wifi Cracker",
                        "Aircrack-ng\t\t(Recommended)", "Fluxion", "Wifiphisher\t\t(Recommended)", "go back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Kismet")
            kismet()        
        elif option == "2":
            print("\n[+] Wifite")
            wifite()        
        elif option == "3":
            print("\n[+] Fern Wifi Cracker")
            fernwificracker()        
        elif option == "4":
            print("\n[+] Aircrack-ng")
            aircrack_ng()    
        elif option == "5":
            print("\n[+] Fluxion")
            fluxion()    
        elif option == "6":
            print("\n[+] Wifiphisher")
            wifiphisher()        
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def kismet():
    github = github_getting_text(
                "https://www.kismetwireless.net/docs/readme/intro/kismet/", 'p', 1)
    template.template("kismet", "kismet", github.strip(), {"Kismet -- WiFi Sniffer": "https://www.kalilinux.in/2019/02/kismet-wifi-sniffer.html", "Use Kismet to Watch Wi-Fi User Activity": "https://null-byte.wonderhowto.com/how-to/use-kismet-watch-wi-fi-user-activity-through-walls-0182214/",
                                                                   "HACKING WIFI USING KISMET": "https://www.bookofnetwork.com/hacking-tutorials/Kismet-Wireless", "How To Use Kismet Kali Linux?": "https://www.systranbox.com/how-to-use-kismet-kali-linux/"})
        
def wifite():
    github = github_getting_text(
                "https://www.kali.org/tools/wifite/", 'p', 1)
    template.template("wifite", "wifite -h", github.strip(), {"Wifite walkthrough Part-1": "https://resources.infosecinstitute.com/topic/wifite-walkthrough-part-1/", "Wifite walkthrough Part-2": "https://resources.infosecinstitute.com/topic/wifite-walkthrough-part-2/",
                                                                      "Wireless pentesting with Wifite": "https://www.hackingarticles.in/wireless-penetration-testing-wifite/", "Wifite - Automated Wifi hacking tool": "https://kalitut.com/wifite-automated-wi-fi-hacking-tool/"})
        
def fernwificracker():
    github = "Fern Wifi Cracker is a Wireless security auditing and attack software program written using the Python Programming Language and the Python Qt GUI library. The program is able to crack and recover WEP/WPA/WPS keys and also run other network based attacks on wireless or ethernet based networks."
    template.template("fern-wifi-cracker", "fern-wifi-cracker", github.strip(), {"What is Fern Wifi Cracker": "https://www.kalilinux.in/2020/09/fern-wifi-cracker.html", "Hacking Wifi networks using Fern Wifi Cracker": "https://www.studocu.com/en-au/document/western-sydney-university/it-product-support-and-services/fern-wifi-cracker-hacking-wifi-networks-using-fern-wifi-cracker-easily/10772514",
                                                                                         "Wireless penetration testing - Fern ": "https://www.hackingarticles.in/wireless-penetration-testing-fern/", "Cracking wifi passwords using Fern": "https://hacking84.rssing.com/chan-13108703/article238.html"})
        
def aircrack_ng():
    github = github_getting_text(
                "https://www.kali.org/tools/aircrack-ng/", 'p', 32)
    template.template("aircrack-ng", "aircrack-ng", github.strip(), {"How to use Aircrack-ng": "https://linuxhint.com/how_to_aircrack_ng/", "Aircrack-ng Practical Demonstration Tutorial": "https://techofide.com/blogs/how-to-use-aircrack-ng-aircrack-ng-tutorial-practical-demonstration/",
                                                                                    "Hacking the wireless network in 5 simple steps": "https://www.hackingloops.com/how-to-use-aircrack-kali/", "Crack WPA/WPA2 WiFi Passwords using Aircrack-ng & Kali Linux": "https://nooblinux.com/crack-wpa-wpa2-wifi-passwords-using-aircrack-ng-kali-linux/"})
        
def fluxion():
    github = github_getting_text(
                "https://fluxionnetwork.github.io/fluxion/", 'p', 1)
    template.template("fluxion", "./fluxion.sh", github.strip(), {"Fluxion kali linux tutorial": "https://linuxhint.com/fluxion-kali-linux-tutorial/", "Fluxion - Wifi security auditing tool": "https://www.hackingloops.com/fluxion/", "Fluxion -- Crack WiFi Passwords in Minutes": "https://www.kalilinux.in/2020/07/fluxion-kali-linux-crack-wifi.html",
                                                                             "Cracking WPA/WPA2 Passwords in Minutes with Fluxion": "https://gbhackers.com/cracking-wpawpa2-passwords-fluxion/amp/", "Wireless Penetration Testing: Fluxion": "https://www.hackingarticles.in/wireless-penetration-testing-fluxion/", "Fluxion in Kali Linux usage": "https://www.cyberpratibha.com/blog/fluxion-wpa-wpa2-hacking/"},method="github", github_install="git clone https://github.com/FluxionNetwork/fluxion.git && cd fluxion", github_check="fluxion")
        
def wifiphisher():
    github = github_getting_text("https://wifiphisher.org/", 'p', 0)
    template.template("wifiphisher", "wifiphisher -h", github.strip(), {"WiFi Exploitation with WifiPhisher": "https://www.hackingarticles.in/wifi-exploitation-wifiphisher/", "wifiphisher Description": "https://en.kali.tools/?p=90", "Read Team engagement on Wifi with Wifiphisher": "https://whitehatinstitute.com/conduct-red-team-engagements-on-wifi-with-wifiphisher/",
                              "Wireless Hacking with WifiPhisher": "https://cntemngwa.medium.com/wireless-hacking-with-wifiphisher-d4b857414146", "WifiPhisher – WiFi Crack and Phishing Framework": "https://latesthackingnews.com/2018/10/02/wifiphisher-wifi-crack-and-phishing-framework/", "Wifiphisher Evil Twin Attack": "https://kalitut.com/wifiphisher-evil-twin-attack/"})


if __name__ == '__main__':
    main()



from cyberonix.main.tools import banner, colors, template,information_gathering,WEB_Application_Analysis,Vulnerability_Analysis,Exploitation_Tools,Session_Management
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Risky Functionality Card Payment")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    "Burp Suite",
                    "Wireshark",
                    "OWASP ZAP",
                    "Nessus",
                    "Sqlmap",
                    "Fiddler",
                    "Metasploit",
                    "Nmap",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if option == "1":
                    print(f"\n[+] Burp Suite")
                    WEB_Application_Analysis.burp_suite()
                elif option == "2":
                    print(f"\n[+] WireShark")
                    Vulnerability_Analysis.wireshark()
                elif option == "3":
                    print(f"\n[+] OwaspZap")
                    WEB_Application_Analysis.owasp_zap()
                elif option == "4":
                    print(f"\n[+] nessus")
                    WEB_Application_Analysis.nessus()
                elif option == "5":
                    print(f"\n[+] Sqlmap")
                    Exploitation_Tools.sqlmap()
                elif option == "6":
                    print(f"\n[+] Fiddler")
                    Session_Management.fiddler()
                elif option == "7":
                    print(f"\n[+] Metasploit")
                    Exploitation_Tools.metasploit()
                elif option == "8":
                    print(f"\n[+] Nmap")
                    information_gathering.nmap()
                elif option == "9":
                    print(f"\n[+] The PenTesters Framework (PTF)")
                    Session_Management.ptf()
                else:
                    break

        elif option == "2":
            print("\n[+] Write-UPS")
            os.system("clear")
            template.template("Writeup","no-tools","Writeups",
                {
                    "Exploiting Payment Gateways": "https://vasuyadav0786.medium.com/exploiting-payment-gateways-97ce7af5a9cf",
                    "Let's Break Into Payment Gateways": "https://infosecwriteups.com/lets-break-into-payment-gateways-fc52523eeaca",
                    "Common Vulnerabilities in Payment Functionality": "https://dl.packetstormsecurity.net/papers/general/common-vulnerabilities.pdf",
                    "Bug Bounty Response Manipulation Leading to Payment Bypass": "https://infosecwriteups.com/bug-bounty-response-manipulation-leading-to-payment-bypass-cb5fde360b1a",
                    "Web Application Security Testing - Testing Payment Functionality": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/10-Test-Payment-Functionality",
                    "Application Security Testing Techniques - Testing Payment Functionality": "https://www.softwaretestinghelp.com/how-to-test-application-security-web-and-desktop-application-security-testing-techniques/",
                    "Parameter Tampering Vulnerability Using 3 Different Approaches": "https://www.cobalt.io/blog/parameter-tampering-vulnerability-using-3-different-approaches",
                    "Webinar: Understanding Payment Gateway Related Vulnerabilities": "https://www.youtube.com/watch?v=oin2fplOazU",
                    "Payment Gateway Security Measures Overview": "https://yashsali7.medium.com/an-overview-of-security-measures-used-in-payment-gateways-86375eb12364",
                    "Payment Bypass Vulnerability on BigBasket": "https://medium.com/@ranjeetjagtap25/payment-bypass-vulnerability-on-bigbasket-2aab137e9631",
                    "Security Features of Payment Gateway": "https://www.ukessays.com/essays/information-technology/security-features-of-payment-gateway-information-technology-essay.php",
                    "Vulnerabilities in Electronic Payment Systems (EPS)": "https://www.linkedin.com/pulse/vulnerabilities-eps-electronic-payment-systems-from-david-joao-",
                    "Security Threats to E-Commerce": "https://www.javatpoint.com/security-threat-to-e-commerce",
                    "Visa's 3-D Secure Secure Online Payment Authentication": "https://www.giac.org/paper/gsec/4380/visa-039-s-3-d-secure-secure-online-payment-authentication/107245",
                    "Researching Xiaomi's TEE": "https://research.checkpoint.com/2022/researching-xiaomis-tee/",
                    "JazzCash Payment Gateway in PHP (Prevent Amount Tampering)": "https://www.youtube.com/watch?v=JEvYSlwb-yY",
                },
                " Risky Functionality Payment Systems Write-UPS",
            )

        else:
            return

if __name__ == "__main__":
    main()



from bs4 import BeautifulSoup
from cyberonix.main.tools import banner, colors, template
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Deniel of Service Attack")
        list_attacks = [
            "GoldenEye",
            "SlowHTTPTest",
            "THC-SSL-DOS",
            "Slowloris",
            "go back",
        ]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] GoldenEye")
            goldeneye()        
            # method=kali
        elif option == "2":
            print("\n[+] Slowhttptest")
            slowhttptest()        
            # method is kali
        elif option == "3":
            print("\n[+] THC-SSL-DOS")
            thc_ssl_dos()        
            # method is kali
        elif option == "4":
            print("\n[+] SlowLoris")
            slowloris()        

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def slowloris():
    github = "Slowloris is a Low bandwidth  HTTP Denial of Service attack that affects threaded servers"
    template.template(
                "slowloris",
                "slowloris.py -h",
                github.strip(),
                {
                    "Slowloris DDOS Attack Tool in Kali Linux": "https://www.geeksforgeeks.org/slowloris-ddos-attack-tool-in-kali-linux/",
                    "What is Slowloris?": "https://www.imperva.com/learn/ddos/slowloris/",
                    "Performing a genuine slowloris attack": "https://ourcodeworld.com/articles/read/962/performing-a-genuine-slowloris-attack-slowhttp-of-indefinite-length-in-kali-linux",
                },)
def thc_ssl_dos():
    github_p1 = github_getting_text(
                "https://www.kali.org/tools/thc-ssl-dos/", "p", 1
            )
    github_p2= github_getting_text("https://www.kali.org/tools/thc-ssl-dos/", "p", 2)
    github_p3= github_getting_text("https://www.kali.org/tools/thc-ssl-dos/", "p", 3)
    github = github_p1.strip().replace("\n", "").replace("\t", "")+github_p2.strip().replace("\n", "").replace("\t", "")+github_p3.strip().replace("\n", "").replace("\t", "")
    template.template(
                "thc-ssl-dos",
                "thc-ssl-dos -h",
                github.strip(),
                {
                    "THC-SSL DoS": "https://www.radware.com/security/ddos-knowledge-center/ddospedia/thc-ssl-dos/",
                    "thc-ssl-dos Usage Example": "https://www.kali.org/tools/thc-ssl-dos/",
                    "THC-SSL-DOS – DoS Tool Against Secure Web-Servers and for Testing SSL-Renegotiation": "https://kalilinuxtutorials.com/thc-ssl-dos/",
                    "The THC SSL DoS Threat": "https://resources.infosecinstitute.com/topic/thc-ssl-dos-threat/",
                },
            )
def slowhttptest():
    github_p1 = github_getting_text(
                "https://www.kali.org/tools/slowhttptest/", "p", 1
            )
    github = github_p1.strip().replace("\n", "").replace("\t", "")
    template.template(
                "slowhttptest",
                "slowhttptest -h",
                github.strip(),
                {
                    'How to perform a DoS attack "Slow HTTP" with SlowHTTPTest': "https://ourcodeworld.com/articles/read/949/how-to-perform-a-dos-attack-slow-http-with-slowhttptest-test-your-server-slowloris-protection-in-kali-linux",
                    "slowhttptest Usage Example": "https://www.kali.org/tools/slowhttptest/",
                    "DoS website using slowhttptest in Kali Linux ": "https://www.blackmoreops.com/2015/06/07/attack-website-using-slowhttptest-in-kali-linux/",
                    "Kali Linux - Stressing Tools": "https://www.tutorialspoint.com/kali_linux/kali_linux_stressing_tools.htm",
                    "How to perform SlowHTTPtest DOS attack ": "https://support.tetcos.com/support/solutions/articles/14000130254-how-to-perform-slowhttptest-dos-attack-through-netsim-emulator-",
                },
            )
def goldeneye():
    github_p1 = github_getting_text(
                "https://www.kali.org/tools/goldeneye/", "p", 0
	                

            )
    github = github_p1.strip().replace("\n", "").replace("\t", "")
    template.template(
                "goldeneye",
                "goldeneye -h",
                github.strip(),
                {
                    "Goldeneye DDos Tool in Kali Linux": "https://www.geeksforgeeks.org/goldeneye-ddos-tool-in-kali-linux/",
                    "Golden Eye DDoS Tool: Installation and Tool usage with examples": "https://allabouttesting.org/golden-eye-ddos-tool-installation-and-tool-usage-with-examples/",
                    "DoS website in Kali Linux using GoldenEye": "https://en.iguru.gr/odigos-epitheseon-ddos-goldeneye/",
                    "DoS website with GoldenEye - Layer 7 DoS tool": "https://www.darkmoreops.com/2014/11/22/dos-website-with-goldeneye/",
                },
            ) 
if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template, waiting, writeup, Configuration_Management
import os
import requests
import requests
import re
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("WEB Application Analysis")
        list_attacks = [" Burp Suite\t\t(Recommended)", " Dirsearch", " Owasp ZAP", " Dirbuster\t\t(Recommended)",
                        " Nikto", " Wapiti", " Nessus\t\t(Recommended)", " dirb", " Nuclei", "ffuf", "go back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print(f"\n[+] Burp Suite")
            burp_suite()
        elif option == "2":
            print(f"\n[+] Dirsearch")
            dirsearch()
        elif option == "3":
            print(f"\n[+] Owasp ZAP")
            owasp_zap()
        elif option == "4":
            Configuration_Management.dirbuster()
        elif option == "5":
            print("\n[+] Nikto")
            nikto()
        elif option == "6":
            print("\n[+] Wapiti")
            wapiti()
        elif option == "7":
            print(f"\n[+] Nessus")
            nessus()
        elif option == "8":
            print(f"\n[+] dirb")
            dirb()
        elif option == "9":
            print(f"\n[+] Nuclei")
            nuclei()
        elif option == "10":
            print("\n[+] ffuf")
            ffuf()
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print(f"Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return "{colors.red}NotLloaded Because No Internet Connection{colors.reset}"


def nikto():
    os.system("clear")
    github = github_getting_text(
                "https://en.wikipedia.org/wiki/Nikto_(vulnerability_scanner)", 'p', 1)
    template.template("nikto", "nikto ", github.strip(), {'What is Nikto and it’s usages ?': 'https://www.geeksforgeeks.org/what-is-nikto-and-its-usages/',
                              'Nikto: A Practical Website Vulnerability Scanner': 'https://securitytrails.com/blog/nikto-website-vulnerability-scanner', 'Nikto Official Docs': 'https://github.com/sullo/nikto/wiki'})


def nuclei():
    os.system("clear")
    github = "Nuclei is a fast vulnerability scanner designed to probe modern applications, infrastructure, cloud platforms, and networks, aiding in the identification and mitigation of exploitable vulnerabilities.At its core, Nuclei uses templates—expressed as straightforward YAML files, that delineate methods for detecting, ranking, and addressing specific security flaws."
    template.template("nuclei", "nuclei", github.strip(), {"Nuclei - Automated Vulnerability Scanning Tool": "https://allabouttesting.org/nuclei-automated-vulnerability-scanning-tool/", "Nuclei – Fast and Customizable Vulnerability Scanner": "https://www.geeksforgeeks.org/nuclei-fast-and-customizable-vulnerability-scanner/",
                              "Gauing+Nuclei for Instant Bounties": "https://infosecwriteups.com/gauing-nuclei-for-instant-bounties-7a8a07979fff ", "DevSecOps 101 Part 3: Scanning Live Web Applications with Nuclei": "https://escape.tech/blog/devsecops-part-iii-scanning-live-web-applications"})

def ffuf():
    os.system("clear")
    github = "ffuf - Fuzz Faster U Fool.The usage examples below show just the simplest tasks you can accomplish using ffuf."
    template.template("ffuf", "ffuf", github.strip(), {"How to Fuzz Web Applications using FFuf – Web Security Tutorial": "https://www.freecodecamp.org/news/web-security-fuzz-web-applications-using-ffuf/",
                                                               "github fuff": "https://github.com/ffuf/ffuf/blob/master/README.md", })
        


def burp_suite():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Burp Suite")
        banner.description("Burp Suite is an integrated platform for performing security testing of web applications. Its various tools work seamlessly together to support the entire testing process, from initialmapping and analysis of an application's attack surface, through to finding and exploiting security vulnerabilities. Burp gives you full control, letting you combine advanced manual techniques with state-of-the-art automation, to make your work faster, more effective, and more fun.")
        ask = template.tool_writeups("burp", " ", " ")
        if ask == "1":
            try:
                professional = input(
                    f"{colors.blue}[+] Do You Want It's Professional Version?(Y/N){colors.reset}")
            except KeyboardInterrupt:
                return
            if professional == "y" or professional == "Y" or professional == "Yes" or professional == "yes":
                # clone repo
                path = 'Burp-Suite'
                isExist = os.path.exists(path)
                if isExist:
                    print(f"{colors.green}[+] It Is Installed{colors.reset}")
                    try:
                        professional = input(
                            f"{colors.blue}[+] Do You Want Run It?(Y/N){colors.reset}")
                    except KeyboardInterrupt:
                        return
                    if professional == "y" or professional == "Y" or professional == "Yes" or professional == "yes":
                        print(
                            f"{colors.yellow}[+] Please Wait....{colors.reset}")
                        os.system(
                            "cd Burp-Suite && bash installed.sh > /dev/null 2>&1")
                else:
                    os.system(
                        "git clone https://github.com/hardikhacker/Burp-Suite")
                    try:
                        professional = input(
                            f"{colors.blue}[+] Do You Want Run It?(Y/N){colors.reset}")
                    except:
                        template.exit_program()
                    if professional == "y" or professional == "Y" or professional == "Yes" or professional == "yes":
                        print(
                            f"{colors.yellow}[+] Please Wait....{colors.reset}")
                        os.system(
                            "cd Burp-Suite && chmod +x * && ./Kali_Linux_Setup.sh > /dev/null 2>&1")
            else:
                print(
                    f"{colors.blue}[+] CHECKING OF COMMUNITY VERSION IS INSTALLED OR NOT{colors.reset}")
                # check for installation
                template.check_installed("burpsuite", "burpsuite")
                waiting.waiting()
        elif ask == "2":
            # first argument for dictionary(key=title,value=url) second argument for banner
            writeup.writeup({"Setting up Burpsuite Professional": "https://github.com/THECH13F/Burp-Suite/blob/main/Readme.md","Top 10 tips for burpsuite": "https://medium.com/r3d-buck3t/top-10-tips-for-burp-suite-72212d22328f", "Setting up burbsuite": "https://thexssrat.medium.com/setting-up-burp-suite-b0a6767d3408", "Burp Suite: Do I need the professional edition?":
                            "https://thexssrat.medium.com/burp-suite-do-i-need-the-professional-edition-bf8c87ce236e", "Burp Suite Extensions to help you Pentest": "https://medium.com/codex/burp-suite-extensions-to-help-you-pentest-97f22a7d7d4d", "FIND MORE resources here": "https://medium.com/search?q=burpsuite"}, "Brup Suit writeup.writeup")
        elif ask == "3":
            template.uninstall_tool("","burp")
        else:
            break


def owasp_zap():
    os.system("clear")
    github = "The OWASP Zed Attack Proxy (ZAP) is an easy to use integrated penetration testing tool for finding vulnerabilities in web applications.It is designed to be used by people with a wide range of security experience and as such is ideal for developers and functional testers who are new to penetration testing as well as being a useful addition to an experienced pen testers toolbox. https://www.owasp.org/index.php/ZAP"
    template.template('zaproxy', 'zaproxy', github.strip(), {"How to setup OWASP ZAP to scan your web application for security vulnerabilities": "https://www.linkedin.com/pulse/how-setup-owasp-zap-scan-your-web-application-security-botla/", "Authenticated Scan using OWASP-ZAP in Windows.": "https://medium.com/@secureica/authenticated-scan-using-owasp-zap-f0a71dafe41",
                      "OWASP ZAP: 6 Key Capabilities and a Quick Tutorial": "https://www.hackerone.com/knowledge-center/owasp-zap-6-key-capabilities-and-quick-tutorial", "Initial Setup": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/untitled", "Setup OWASP ZAP": "https://infosecgirls.gitbook.io/infosecgirls-training/v/appsec/initial-setup-with-owasp-zap/setup-owasp-zap"})


def nessus():
    os.system("clear")
    version_grab = github_getting_text("https://www.tenable.com/downloads/nessus?loginAttempted=true",
                                          'div[class="multi-select__single-value css-1uccc91-singleValue"]', 0).strip()
    version = version_grab.strip().replace(" ", "")
    github = "Nessus is a platform developed by Tenable that scans for security vulnerabilities in devices, applications, operating systems, cloud services and other network resources.Originally launched as an open source tool in 1998, its enterprise edition became a commercial product in 2005. Nessus now encompasses several products that automate point-in-time vulnerability assessments of a network's attack surface, with the goal of enabling enterprise IT teams to stay ahead of cyber attackers by proactively identifying and fixing vulnerabilities as the tool discovers them, rather than after attackers exploit them.Nessus identifies software flaws, missing patches, malware, denial-of-service vulnerabilities, default passwords and misconfiguration errors, among other potential flaws. When Nessus discovers vulnerabilities, it issues an alert that IT teams can then investigate and determine what -- if any -- further action is required."
    template.template("nessus", "nessus", github.strip(), {"How To: Run Your First Vulnerability Scan with Nessus": "https://www.tenable.com/blog/how-to-run-your-first-vulnerability-scan-with-nessus", "A brief introduction to the Nessus vulnerability scanner": "https://resources.infosecinstitute.com/topic/a-brief-introduction-to-the-nessus-vulnerability-scanner/",
                      "Beginner’s Guide to Nessus": "https://www.hackingarticles.in/beginners-guide-to-nessus/", "Nessus Ubuntu Installation and Tutorial": "https://linuxhint.com/nessus-ubuntu-installation-tutorial/"}, link=f"https://www.tenable.com/downloads/api/v2/pages/nessus/files/{version}-debian10_amd64.deb", method="deb")



def dirb():
    os.system("clear")
    github = "DIRB IS a Web Content Scanner. It looks for existing (and/or hidden) Web Objects. It basically works by launching a dictionary basesd attack against a web server and analizing the response"
    template.template("dirb", "dirb", github.strip(), {"Dirb — A web content scanner": "https://medium.com/tech-zoom/dirb-a-web-content-scanner-bc9cba624c86", "Footprinting and Reconnaissance with DIRB Tool (For Security Researcher and Bug Bounty Hunters":
                      "https://www.openbugbounty.org/blog/mas00712/footprinting-and-reconnaissance-with-dirb-tool-for-security-researcher-and-bug-bounty-hunters/", "Comprehensive Guide on Dirb Tool": "https://www.hackingarticles.in/comprehensive-guide-on-dirb-tool/"})


def dirsearch():
    os.system("clear")
    github = "As a feature-rich tool, dirsearch gives users the opportunity to perform a complex web content discovering, with many vectors for the wordlist, high accuracy, impressive performance, advanced connection/request settings, modern brute-force techniques and nice output."
    template.template("dirsearch", "dirsearch --help ", github.strip(), {"Dirserach helpfile": "https://www.kali.org/tools/dirsearch/",
                      "Find Hidden Web Directories with Dirsearch ": "https://null-byte.wonderhowto.com/how-to/find-hidden-web-directories-with-dirsearch-0201615/", })


def wapiti():
    os.system("clear")
    github = github_getting_text("https://wapiti-scanner.github.io/", 'p', 6)
    github = re.sub(r'\s+', ' ', github).strip()
    template.template("wapiti", "wapiti", github.strip(), {"wapiti free web application vulnerability scanner": "https://pentestit.medium.com/wapiti-free-web-application-vulnerability-scanner-ce7712adf644", "Official docs": "https://github.com/wapiti-scanner/wapiti", "wapiti tutorial":
                      "https://www.kalilinux.in/2021/01/wapiti-tutorial.html", "complete guide to using wapiti web vulnerability scanner to keep your web applications websites secure": "https://linuxsecurity.com/features/complete-guide-to-using-wapiti-web-vulnerability-scanner-to-keep-your-web-applications-websites-secure"})


if __name__ == "__main__":
    main()



import os
from cyberonix.main.tools import template,banner,colors,information_gathering,Vulnerability_Analysis,Password_Hacking,WEB_Application_Analysis,Exploitation_Tools,Configuration_Management,run_on_browser
import requests
from bs4 import BeautifulSoup

def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Bug Bounty")
        list_root_attacks = ["Bug Bounty Video Series","Reconnaissance", "Intel Discovery", "Enumeration","Vulnerability Analysis","Exploitation","Reporting", "go back"]
        for i in range(len(list_root_attacks)):
            print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            run_on_browser.main("https://github.com/defronixpro/Defronix-Cybersecurity-Roadmap/blob/main/README.md#bug-bounty")
        elif option == "2":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Reconnaissance")
                banner.description("Bug Bounty phase in reconnaissance involves ethical hackers discovering vulnerabilities in systems for rewards, enhancing cybersecurity by identifying weaknesses before malicious actors exploit them")
                list_root_attacks = ["Search Engines", "Tools","Usefull Websites", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+] Search Engines")
                    os.system("clear")
                    template.template("Search Engines", "no-tools","Best Serach Engines",
                                       {
                                           "Google": "https://www.google.com/",
                                           "DuckDuckGO":"https://duckduckgo.com/",
                                           "Shodan":"https://www.shodan.io/",
                                           "Censys":"https://search.censys.io/",
                                           "Bing":"https://www.bing.com/",
                                           "Starpage":"https://www.startpage.com/",
                                           "Ecosia":"https://www.ecosia.org/",
                                           "Brave":"https://search.brave.com/",
                                           "Yandex":"https://yandex.com/",
                                           "Ahmia":"https://ahmia.fi/",
                                           "Yahoo":"https://www.yahoo.com/",
                                           
                                       })
                elif ask == "2":
                    while True:
                        os.system("clear")
                        banner.main()
                        banner.attack("Tools")
                        banner.description("Reconnaissance Tools.")
                        list_root_attacks = [" Nmap\t\t(Recommended)"," Recon-ng\t\t(Recommended)"," theHarvester"," Subfinder\t\t(Recommended)"," Sublist3r"," SpiderFoot"," Amass\t\t(Recommended)"," Legion"," Netdiscover\t(Recommended)","Unicornscan","Feroxbuster","go back"]
                        for i in range(len(list_root_attacks)):
                            print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                        try:
                            vuln = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                        except KeyboardInterrupt:
                            return
                        if vuln == "1":
                            print("\n[+] Nmap")
                            information_gathering.nmap() 
                        elif vuln == "2":
                            print("\n[+] Recon-ng")
                            information_gathering.recon_ng()
                        elif vuln == "3":
                            print("\n[+] TheHarvester")
                            information_gathering.theharvester()
                        elif vuln == "4":
                            print("\n[+] subfinder")
                            information_gathering.subfinder()
                        elif vuln == "5":
                            print("\n[+] sublist3r")
                            information_gathering.sublist3r()
                        elif vuln == "6":
                            print("\n[+] spiderfoot")
                            information_gathering.spiderfoot()
                        elif vuln == "7":
                            print("\n[+] amass")
                            information_gathering.amass()
                        elif vuln == "8":
                            print("\n[+] legion")
                            Vulnerability_Analysis.legion()
                        elif vuln == "9":
                            print("\n[+]Netdiscover")
                            information_gathering.netdiscover()
                        elif vuln == "10":
                            print("\n[+] Unicornscan")
                            unicorn()
                        elif vuln == "11":
                            print("\n[+] Feroxbuster")
                            Configuration_Management.feroxbuster()
                        else:
                            break
                        
                elif ask == "3":
                    print("\n[+] Useful Websites")
                    os.system("clear")
                    template.template("Useful Websites","no-tools",'This is website for Bug Bounty',{
                            " Social-Search Website":"https://www.social-searcher.com/",
                            " IP2info":"https://ipinfo.io/",
                            " Viewdns":"https://viewdns.info/", 
                            " Wayback Machine":"https://archive.org/web/",
                            " Dnsdumpster":"https://dnsdumpster.com/",
                            " MXToolbox":"https://mxtoolbox.com/",
                            " Lopseg":"https://www.lopseg.com.br/osint",
                            " Arin whois":"https://whois.arin.net/ui/",
                            " Dnschecker":"https://dnschecker.org/",
                            "BGP-Toolkit":"https://bgp.he.net/",
                            "Mattw.io":"https://mattw.io/",
                            "Searchftps":"https://www.searchftps.net/",
                            "Security Headers":"https://securityheaders.com/",
                            "Robtex":"https://www.robtex.com/",
                            "Builtwith":"https://builtwith.com/",
                            "Intodns":"https://www.intodns.com/",
                            "Serachdns":"https://searchdns.netcraft.com/",
                            "Hackertarget":"https://hackertarget.com/",
                            "Vulners":"https://vulners.com/",
                            "cvedetails":"https://www.cvedetails.com/",
                            "Zero Day initiative":"https://www.zerodayinitiative.com/",})
                else:
                     break

        elif option == "3":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Discovery tools")
                banner.description("Intel Discovery in the context of bug bounty refers to Intel's bug bounty program, which aims to identify and address security vulnerabilities in their products. Researchers and ethical hackers are invited to discover and report security flaws in Intel hardware, software, and firmware. In return, they may receive monetary rewards, recognition, and the opportunity to help improve the security of Intel products. The program emphasizes responsible disclosure, meaning vulnerabilities should be reported privately to Intel to allow them to fix the issues before public disclosure.")
                list_root_attacks = ["Burpsuite\t\t(Recommended)","Owasp Zap\t\t(Recommended)","Nessus\t\t(Recommended)","Metasploit framework(Recommended)", "Dirb ","Dirsearch ","Gobuster\t\t(Recommended) ","go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+] Burpsuite")
                    WEB_Application_Analysis.burp_suite()
                elif ask == "2":
                    print("\n[+] Owasp Zap")
                    WEB_Application_Analysis.owasp_zap()
                elif ask == "3":
                    print("\n[+] Nessus")
                    WEB_Application_Analysis.nessus()
                elif ask == "4":
                    print("\n[+] Metasploit-Framework")
                    Exploitation_Tools.metasploit()
                elif ask == "5":
                    print("\n[+] Dirb")
                    WEB_Application_Analysis.dirb()
                elif ask == "6":
                    print("\n[+] Dirsearch")
                    WEB_Application_Analysis.dirsearch()
                elif ask == "7":
                    print("\n[+] Gobuster")
                    Configuration_Management.gobuster()
                else:
                     break
                
        elif option == "4":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Enumeration")
                banner.description("Enumeration in bug bounty refers to the process of systematically gathering information about a target system to identify potential entry points for exploitation. This can include discovering subdomains, open ports, services running on those ports, directories, files, and user accounts. Enumeration is a crucial step in the reconnaissance phase of a bug bounty program, as it helps bug hunters map the attack surface and uncover vulnerabilities that can be exploited.")
                list_root_attacks = ["Nmap\t\t(Recommended)","Unicornscan","Masscan\t\t(Recommended)","Nikto ","DNSRecon\t\t(Recommended)","go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+] Nmap")
                    information_gathering.nmap()
                elif ask == "2":
                    print("\n[+] Unicornscan")
                    unicorn()
                elif ask == "3":
                    print("\n[+] Masscan")
                    masscan()
                elif ask == "4":
                    print("\n[+] Nikto")
                    Vulnerability_Analysis.nikto()
                elif ask == "5":
                    print("\n[+] Dnsrecon")
                    dnsrecon()
                else:
                     break

        elif option == "5":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Vulnerability Analysis")
                banner.description("Vulnerability Analysis in bug bounty refers to the process of identifying, evaluating, and prioritizing security weaknesses in a target system. This involves examining the system's components, configurations, and code to find potential vulnerabilities that could be exploited by attackers. Bug hunters use various tools and techniques during this phase to detect issues such as SQL injection, cross-site scripting (XSS), and insecure configurations. The goal of vulnerability analysis is to understand the nature and impact of the discovered weaknesses, allowing for effective reporting and remediation.")
                list_root_attacks = ["Wpscan","Burpsuite\t\t(Recommended)","OWASP ZAP\t\t(Recommended)","Nessus\t\t(Recommended)","Sqlmap\t\t(Recommended)","go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+] Wpscan")
                    Vulnerability_Analysis.wpscan()
                elif ask == "2":
                    print("\n[+] Burpsuite")
                    WEB_Application_Analysis.burp_suite()
                elif ask == "3":
                    print("\n[+] Owasp Zap")
                    WEB_Application_Analysis.owasp_zap()
                elif ask == "4":
                    print("\n[+] Nessus")
                    WEB_Application_Analysis.nessus()
                elif ask == "5":
                    print("\n[+] Sqlmap")
                    Exploitation_Tools.sqlmap()
                else:
                     break
                
        elif option == "6":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Exploitation")
                banner.description("Exploitation in bug bounty refers to the phase where a bug hunter attempts to leverage identified vulnerabilities to execute attacks on a target system. The objective is to demonstrate the practical impact of a vulnerability, such as gaining unauthorized access, escalating privileges, or exfiltrating sensitive data. This step often involves crafting and executing specific exploits to prove that the vulnerability can be used in a real-world scenario. Successful exploitation helps validate the severity of the vulnerability, guiding the target organization on necessary remediation actions.")
                list_root_attacks = ["Crackmapexec\t(Recommended)","Masscan","Beef\t\t(Recommended)","Social Engineering Toolkit","PowerSploit","Mimikatz\t\t(Recommended)","go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+] Crackmapexec")
                    Exploitation_Tools.crackmapexec()
                elif ask == "2":
                    print("\n[+] Masscan")
                    masscan()
                elif ask == "3":
                    print("\n[+] beef")
                    Exploitation_Tools.beef()
                elif ask == "4":
                    print("\n[+]Social Engineering Toolkit")
                    Password_Hacking.setoolkit()
                elif ask == "5":
                    print("\n[+]powersploit")
                    powersploit()               
                elif ask == "6":
                    print("\n[+]mimikatz")
                    mimikatz()                
                elif ask == "7":
                    print("\n[+]httpx-toolkit")
                    httpx_toolkit()         
                else:
                     break   

        elif option == "7":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Reporting Tools")
                banner.description("Reporting tools in bug bounty are specialized software or platforms that help bug hunters document and submit their findings to the target organization. These tools facilitate the structured reporting of vulnerabilities, including details such as the type of vulnerability, steps to reproduce it, potential impact, and suggested mitigations. ")
                list_root_attacks = ["Dradis","CherryTree\t\t(Recommended)","faradaystart","recordmydesktop ","pipal","maltego\t\t(Recommended)","go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    print("\n[+]Dradis")
                    dradis()               
                elif ask == "2":
                    print("\n[+]Cherrytree")
                    cherrytree()                
                elif ask == "3":
                    print("\n[+]faraday")
                    faraday()                    
                elif ask == "4":
                    print("\n[+]recordmydesktop")
                    recordmydesktop()                    
                elif ask == "5":
                    print("\n[+]pipal")
                    pipal ()               
                elif ask == "6":
                    print("\n[+] Maltego")
                    information_gathering.maltego()
                else:
                     break  
        else:
            return            

def recordmydesktop():
    os.system("clear")
    github ="recordmydesktop application produces an ogg-encapsulated theora-vorbis file. recordMyDesktop tries to be as unobstrusive as possible by proccessing only regions of the screen that have changed."
    template.template("recordmydesktop","recordmydesktop --help",github.strip(),{"How to record screencasts with recordMyDesktop":"https://opensource.com/business/15/11/how-record-screencasts","recordmydesktop Tool help file":"https://www.kali.org/tools/recordmydesktop/",})
                
def faraday():
    os.system("clear")
    github ="Faraday introduces a new concept (IPE) Integrated Penetration-Test Environment a multiuser Penetration test IDE. Designed for distribution, indexation and analysis of the generated data during the process of a security audit."  
    template.template("faraday","faraday --help",github.strip(),{"faraday Tool Documentation":"https://www.kali.org/tools/python-faraday/#tool-documentation","How to scan web sites with Faraday IDE on Kali Linux":"https://www.securityhardening.com/library/Article33.pdf",})
                
def cherrytree():
    os.system("clear")
    github ="CherryTree is a hierarchical note taking application, featuring rich text, syntax highlighting, images handling, hyperlinks, import/export with support for multiple formats, support for multiple languages, and more."
    template.template("cherrytree","cherrytree --help",github.strip(),{"How To Install cherrytree on Kali Linux":"https://installati.one/install-cherrytree-kalilinux/","Cherry tree General Commands Manual":"https://www.kali.org/tools/cherrytree/#tool-documentation",})
                
def dradis():
    os.system("clear")
    github ="Dradis is an open-source collaboration framework, tailored to InfoSec teams."
    template.template("dradis","dradis --help",github.strip(),{"dradis helpfile":"https://www.kali.org/tools/dradis/","Dradis: Reporting and Collaboration Tool":"https://www.hackingarticles.in/dradis-reporting-and-collaboration-tool/","dradis github":"https://github.com/dradis/dradis-ce",})
                
def pipal():
    os.system("clear")
    github ="On most internal pen-tests I do, I generally manage to get a password dump from the DC. To do some basic analysis on this I wrote Counter and since I originally released it I have made quite a few mods to it to generate extra stats that are useful when doing reports to management."
    template.template("pipal","pipal --help",github.strip(),{"pipal Help file":"https://www.kali.org/tools/pipal/#tool-documentation","Password Cracking Strategy: Using pipal to Determine Common Password Patterns":"https://www.hackers-arise.com/post/password-cracking-strategy-using-pipal-to-determine-password-patterns",})
                
def httpx_toolkit():
    os.system("clear")
    github ="httpx is a fast and multi-purpose HTTP toolkit allow to run multiple probers using retryablehttp library, it is designed to maintain the result reliability with increased threads."
    template.template("httpx-toolkit","httpx-toolkit --help",github.strip(),{"httpx-toolkit kali":"https://www.kali.org/tools/httpx-toolkit/","A Detailed Guide on httpx":"https://www.hackingarticles.in/a-detailed-guide-on-httpx/",})
                
def mimikatz():
    os.system("clear")
    github ="Mimikatz uses admin rights on Windows to display passwords of currently logged in users in plaintext."
    template.template("mimikatz","mimikatz --help",github.strip(),{"Mimikatz tutorial: How it hacks Windows passwords, credentials":"https://www.techtarget.com/searchsecurity/tutorial/Mimikatz-tutorial-How-it-hacks-Windows-passwords-credentials","What is Mimikatz? The Beginner's Guide":"https://www.varonis.com/blog/what-is-mimikatz","What Is Mimikatz? Everything You Need to Know":"https://www.cynet.com/network-attacks/mimikatz/",})
                
def powersploit():
    os.system("clear")
    github ="PowerSploit is a series of Microsoft PowerShell scripts that can be used in post-exploitation scenarios during authorized penetration tests."
    template.template("powersploit","powersploit --help",github.strip(),{"How to Use PowerSploit, Part 1 (Evading Antivirus Software)":"https://null-byte.wonderhowto.com/how-to/hack-like-pro-use-powersploit-part-1-evading-antivirus-software-0165535/",})
                
def dnsrecon():
    os.system("clear")
    github="DNSRecon is a Python port of a Ruby script that I wrote to learn the language and about DNS in early 2007.This time I wanted to learn about Python and extend the functionality of the original tool and in the process re-learn how DNS works and how could it be used in the process of a security assessment and network troubleshooting."
    template.template("dnsrecon","dnsrecon --help",github.strip(),{"dnsrecon Documentation":"https://www.kali.org/tools/dnsrecon/","DNSRecon: a powerful DNS reconnaissance tool":"https://securitytrails.com/blog/dnsrecon-tool","DNSRecon Cheat Sheet":"https://www.eccouncil.org/wp-content/uploads/2023/09/DNSRecon-Cheat-Sheet-3.pdf",})
                
                         
def unicorn():
    os.system("clear")
    github = "Unicornscan is a new information gathering and correlation engine built for and by members of the security research and testing communities. It was designed to provide an engine that is Scalable, Accurate, Flexible, and Efficient."
    template.template("unicornscan","unicornscan -h",github.strip(),{"Unicornscan Penetration Testing Tool in Kali Linux":"https://www.geeksforgeeks.org/unicornscan-penetration-testing-tool-in-kali-linux/","Reconnaissance with Unicornscan":"https://www.hackers-arise.com/post/2017/08/20/reconnaissance-with-unicornscan",})

def masscan():
    os.system("clear")
    github="MASSCAN is TCP port scanner which transmits SYN packets asynchronously and produces results similar to nmap, the most famous port scanner. Internally, it operates more like scanrand, unicornscan, and ZMap, using asynchronous transmission. It’s a flexible utility that allows arbitrary address and port ranges."
    template.template("masscan","masscan --help",github.strip(),{"masscan Documentation":"https://www.kali.org/tools/masscan/","Masscan -- 1000 Times Faster Than NMAP":"https://www.kalilinux.in/2020/09/masscan-1000-times-faster-than-nmap.html","Masscan Cheatsheet":"https://cheatsheet.haax.fr/network/port-scanning/masscan_cheatsheet/",})


if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,WEB_Application_Analysis,Exploitation_Tools,Vulnerability_Analysis,information_gathering
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Configuration Management")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    " Dirb",
                    " Gobuster",
                    " Nikto",
                    " Wfuzz",
                    " Dirbuster",
                    " Feroxbuster",
                    " Nmap",
                    " HTTPie",
                    " Metasploit",
                    "SecurityHeaders",
                    "SQLmap",
                    "TruffleHog",
                    "SecretFinder",
                    "Go Back"
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if option == "1":
                    print("\n[+] Dirb")
                    WEB_Application_Analysis.dirb()
                elif option == "2":
                    print("\n[+] Gobuster")
                    gobuster()
                elif option == "3":
                    print("\n[+] Nikto")
                    WEB_Application_Analysis.nikto()
                elif option == "4":
                    print("\n[+] Wfuzz")
                    Vulnerability_Analysis.wfuzz()
                elif option == "5":
                    print("\n[+] Dirbuster")
                    dirbuster()
                elif option == "6":
                    print("\n[+] Feroxbuster")
                    feroxbuster()
                elif option == "7":
                    print("\n[+] Nmap")
                    information_gathering.nmap()
                elif option == "8":
                    print("\n[+] HTTPie")
                    httpie()                
                elif option == "9":
                    print("\n[+] Metasploit")
                    Exploitation_Tools.metasploit()
                elif option == "10":
                    print("\n[+] SecurityHeaders")
                    securityheaders()                
                elif option == "11":
                    print("\n[+] Sqlmap")
                    Exploitation_Tools.sqlmap()
                elif option == "12":
                    print("\n[+] TruffleHog")
                    trufflehog()                
                elif option == "13":
                    print("\n[+] SecretFinder")
                    secretfinder()              
                else:
                    break

        elif option == "2":
            print("\n[+] Write-UPS")
            os.system("clear")
            template.template("Writeup","no-tools","Writeups",
                {
            "Configuration management in penetration testing": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/README",
            "How to find Exposed backup and unreferenced files": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/04-Review_Old_Backup_and_Unreferenced_Files_for_Sensitive_Information",
            "Review Old Backup and Unreferenced Files for Sensitive Information": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/04-Review_Old_Backup_and_Unreferenced_Files_for_Sensitive_Information",
            "Multiple Ways to Detect HTTP Options": "https://www.hackingarticles.in/multiple-ways-to-detect-http-options/",
            "security HTTP headers scanning and details": "https://www.atatus.com/tools/security-header",
            "Testing for Content Security Policy": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/12-Test_for_Content_Security_Policy",
            "Test Network Infrastructure Configuration": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/02-Configuration_and_Deployment_Management_Testing/01-Test_Network_Infrastructure_Configuration",
            "Testing applications in production vs. non-production benefits": "https://www.techtarget.com/searchsecurity/tip/Testing-applications-in-production-vs-non-production-benefits",
            "How to Scan GitHub Repository for Credentials": "https://geekflare.com/github-credentials-scanner/",
                },
                "Configuration-Management Writeups",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"
        
def secretfinder():
    os.system("clear")
    github = "SecretFinder is an open-source tool used to scan web applications for sensitive information and secrets, such as API keys, passwords, and tokens. It is designed to identify potential security vulnerabilities that could be exploited by attackers, and can be used in bug bounty hunting and vulnerability assessments. SecretFinder uses a combination of static analysis and dynamic analysis techniques to discover secrets, and can be customized with various options and configurations to suit specific use cases. It generates a report of its findings, which can be used to remediate identified vulnerabilities and improve the overall security of the web application. SecretFinder is a powerful and efficient tool that can help security professionals and developers identify potential security risks in their web applications."
    template.template(
                        "secretFinder",
                        "python3 SecretFinder.py -h",
                        github.strip(),
                        {
                            "SecretFinder demo": "https://www.briskinfosec.com/tooloftheday/toolofthedaydetail/SecretFinder",
                        },
                        method="github",
                        github_install="git clone https://github.com/m4ll0k/SecretFinder.git && cd SecretFinder && pip install -r requirements.txt",
                        github_check="SecretFinder",
                    )
def trufflehog():
    os.system("clear")
    github = "Trufflehog is an open-source tool used for searching and identifying sensitive information and secrets, such as API keys, passwords, and private keys, in source code repositories. It is designed to scan code repositories for potential security vulnerabilities that could be exploited by attackers, and can be used in bug bounty hunting and vulnerability assessments. Trufflehog uses advanced techniques, such as entropy analysis and regular expressions, to identify potential security issues, and generates a report of its findings. It is a powerful and flexible tool that can help security professionals and developers identify potential security risks in their code."
    template.template(
                        "trufflehog",
                        "trufflehog -h",
                        github.strip(),
                        {
                            "Usage": "https://github.com/trufflesecurity/trufflehog",
                            "Finding Secrets in Git Repos with TruffleHog": "https://materials.rangeforce.com/tutorial/2020/03/16/TruffleHog/",
                        },
                    )
def securityheaders():
    os.system("clear")
    github = """SecurityHeaders is a configuration management tool that focuses on securing web applications by helping administrators configure appropriate HTTP security headers. HTTP security headers are additional response headers that can be sent by a web server to a client's browser to instruct it to follow certain security-related behaviors. For example, the "Content-Security-Policy" header can be used to restrict the types of content that a web page can load, helping to prevent cross-site scripting (XSS) attacks."""
    template.template(
                        "securityheaders",
                        "python3 securityheaders.py -h",
                        github.strip(),
                        {
                            "Website": "https://securityheaders.com/",
                            "Securityheaders usage": "https://github.com/koenbuyens/securityheaders",
                        },
                        method="github",
                        github_install="git clone https://github.com/koenbuyens/securityheaders.git && cd securityheaders && pip install -r requirements.txt",
                        github_check="securityheaders",
                    )
def httpie():
    os.system("clear")
    github = "HTTPie is a command-line tool used to send HTTP requests and receive responses from a server. It is designed to be user-friendly and intuitive, with a simple syntax and easy-to-read output. HTTPie can be used to test and debug APIs, as well as interact with web services and applications. It supports various HTTP methods, data formats, and authentication methods, and can be customized with various options and configurations to suit specific use cases."
    template.template(
                        "httpie", "httpie -h", github.strip(), "no-writeups"
                    )
def gobuster():
	os.system("clear")
	github = """Gobuster is an open-source tool used by security professionals and penetration testers to perform web content discovery and directory/file enumeration on a target website. It is a popular tool used in bug bounty hunting and vulnerability assessments. The tool works by launching a series of HTTP requests to the target website and analyzing the responses to discover hidden directories, files, and other web resources that may not be easily discoverable through normal browsing. It uses a wordlist of common directory and file names, as well as brute-force techniques to guess the names of hidden directories and files."""
	template.template(
                        "gobuster",
                        "gobuster -h",
                        github.strip(),
                        {
                            "Gobuster Complete tutorial": "https://hackertarget.com/gobuster-tutorial/",
                            "Scan Websites for Interesting Directories using Gobuster": "https://null-byte.wonderhowto.com/how-to/scan-websites-for-interesting-directories-files-with-gobuster-0197226/",
                            "How to use Gobuster for Scanning Website’s Subdomains & Directories": "https://spinningsecurity.com/how-to-use-gobuster-for-scanning-websites/",
                        },)


def dirbuster():
	os.system("clear")
	github = "DirBuster is a web application scanner designed to brute force directories and files names on web servers. It is a Java-based tool and can be used to discover hidden content, sensitive files, and directories that are not exposed through normal web browsing. DirBuster is also capable of detecting common web application vulnerabilities such as SQL injection, file inclusion, and cross-site scripting. The tool has an easy to use graphical user interface, and users can customize the wordlist to use in the directory and file name brute force. It is widely used by security professionals, penetration testers, and bug bounty hunters to identify security issues in web applications."
	template.template(
                        "dirbuster", "dirbuster -h", github.strip(), "no-writeups"
                    )
                   
def feroxbuster():
	os.system("clear")
	github = "Feroxbuster is an open-source content discovery and directory/file enumeration tool used in bug bounty hunting and web application security assessments. It quickly scans a target website for hidden directories, files, and other resources using a variety of techniques and generates a report of its findings."
	template.template(
                        "feroxbuster", "feroxbuster -h", github.strip(), "no-writeups"
                    )
if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,WEB_Application_Analysis,information_gathering
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Session Management")
        list_attacks = ["Tools", "Writeups", "Burp Extensions", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                print("\n[+] Tools")
                os.system("clear")
                banner.main()
                banner.attack("Tools")
                list_attacks = [
                    "OWASP ZAP",
                    "BurpSuite",
                    "Nikto",
                    "Nmap",
                    "Wapiti",
                    "Nessus",
                    "Nuclei",
                    "Fiddler",
                    "Penetration Testers Framework (PTF)",
                    "Go Back",
                ]
                for i in range(len(list_attacks)):
                    print(
                        colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if option == "1":
                    os.system("clear")
                    WEB_Application_Analysis.owasp_zap()
                elif option == "2":
                    os.system("clear")
                    WEB_Application_Analysis.burp_suite()
                elif option == "3":
                    os.system("clear")
                    WEB_Application_Analysis.nikto()
                elif option == "4":
                    os.system("clear")
                    information_gathering.nmap()
                elif option == "5":
                    os.system("clear")
                    WEB_Application_Analysis.wapiti()
                elif option == "6":
                    os.system("clear")
                    WEB_Application_Analysis.nessus()
                elif option == "7":
                    os.system("clear")
                    WEB_Application_Analysis.nuclei()
                elif option == "8":
                    os.system("clear")
                    fiddler()                
                elif option == "9":
                    os.system("clear")
                    ptf()                
                else:
                    break

        elif option == "2":
            print("\n[+] Write-UPS")
            os.system("clear")
            template.template("Writeup","no-tools","Writeups",
                {
                    "Session Management - Authgear": "https://www.authgear.com/post/session-management",
                    "OWASP Session Management Cheat Sheet": "https://cheatsheetseries.owasp.org/cheatsheets/Session_Management_Cheat_Sheet.html",
                    "Session Management Overview - Secure Coding": "https://www.securecoding.com/blog/session-management-an-overview/",
                    "Session Management Best Practices - Packetlabs": "https://www.packetlabs.net/posts/session-management/",
                    "HTTP Sessions - MDN Web Docs": "https://developer.mozilla.org/en-US/docs/Web/HTTP/Session",
                    "Attacking Session Management with Burp Suite": "https://portswigger.net/support/using-burp-to-attack-session-management",
                    "Session Management Lecture Notes - Stanford": "https://crypto.stanford.edu/cs155old/cs155-spring16/lectures/10-SessionMgmt.pdf",
                    "Broken Authentication and Session Management - Crashtest Security": "https://crashtest-security.com/broken-authentication-and-session-management/",
                    "Preventing Security Voids in Web Applications - SANS Institute": "https://sansorg.egnyte.com/dl/CmpHWTzrja",
                    "PHP Session Security Management - PHP.net": "https://www.php.net/manual/en/features.session.security.management.php",
                    "Session Management in ColdFusion - CFDocs": "https://cfdocs.org/security-session-management",
                    "Comprehensive Guide on Broken Authentication and Session Management - Hacking Articles": "https://hackingarticles.in/comprehensive-guide-on-broken-authentication-session-management/",
                    "What is Session Management? - Clerk.dev": "https://clerk.dev/blog/what-is-session-management",
                    "All You Need to Know About User Session Security - SuperTokens": "https://supertokens.com/blog/all-you-need-to-know-about-user-session-security",
                    "How to Secure Authentication, Session Management, and Access Control Systems of Your Web Applications - Vaadata": "https://www.vaadata.com/blog/how-to-secure-authentication-session-management-and-access-control-systems-of-your-web-applications/",
                    "Understanding Session Management - Coveros": "https://www.coveros.com/understanding-session-management-one-of-owasp-top-10-part-1/",
                    "Broken Authentication and Session Management Tips - Hacklido": "https://hacklido.com/blog/207-broken-authentication-and-session-management-tips",
                    "Web Security Session Management Slide": "https://slideplayer.com/slide/5689194/#.XFSQwUKWre4.twitter",
                    "Attacking Session Management - OWASP": "https://owasp.org/www-pdf-archive//Attacking_Session_Management_-_Alexandre_Villas.pdf",
                    "Improving the Security of Session Management in Web Applications - OWASP": "https://owasp.org/www-pdf-archive//Improving_the_Security_of_Session_Management_in_Web_Applications_-_Philippe_De_Ryck.pdf",
                    "Session Management - OWASP 2011": "https://owasp.org/www-pdf-archive//OWASP_2011_-_Slawomir_Rozbicki_-_Session_Managemnt.pdf",
                    "Session Fixation - OWASP AppSec Research 2010": "https://owasp.org/www-pdf-archive//OWASP_AppSec_Research_2010_Session_Fixation_by_Schrank_Braun_Johns_and_Poehls.pdf",
                    "Session Hijacking: Danger on the Network - OWASP": "https://owasp.org/www-pdf-archive//Sessi%C3%B3n_Hijacking_Peligro_en_la_Red.pdf",
                    "Mastering Session Management - Siva Ram - PDF": "https://owasp.org/www-pdf-archive//Siva_Ram-Mastering_Session_Managment.pdf",
                    "Application Session Management Best Practices": "https://auth0.com/blog/application-session-management-best-practices/",
                },
                "Session Management Write-UPS",
            )

        elif option == "3":
            print("\n[+] Burp Extensions")
            os.system("clear")
            template.template("Burp Extensions","no-tools","Writeups",
                {
                    "PortSwigger - Session Timeout Test": "https://portswigger.net/bappstore/c4bfd29882974712a1d69c6d8f05874e",
                    "PortSwigger - CSRF Scanner": "https://portswigger.net/bappstore/60f172f27a9b49a1b538ed414f9f27c3",
                    "PortSwigger - Token Extractor": "https://portswigger.net/bappstore/f24211fa6fcd4bbea6b21f99c5cad27a",
                    "PortSwigger - Headers Analyzer": "https://portswigger.net/bappstore/8b4fe2571ec54983b6d6c21fbfe17cb2",
                    "PortSwigger - J2EE Scan": "https://portswigger.net/bappstore/7ec6d429fed04cdcb6243d8ba7358880",
                    "PortSwigger - CO2": "https://portswigger.net/bappstore/c5071c7a7e004f72ae485e8a72911afc",
                    "PortSwigger - WS Security": "https://portswigger.net/bappstore/i5431k07za13636g0o9a1733ke7h10g3",
                    "PortSwigger - JWT Editor": "https://portswigger.net/bappstore/26aaa5ded2f74beea19e2ed8345a93dd",
                    "Github - WS-Attacker": "https://github.com/RUB-NDS/WS-Attacker",
                    "Github - logger++": "https://github.com/PortSwigger/logger-plus-plus",
                },
                "Session Management Burp Extensions",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def fiddler():
    github = github_getting_text(
                        "https://learn.microsoft.com/en-us/windows/win32/win7appqual/fiddler-web-debugger-tool/",
                        "p",
                        2,
                    )
    template.template(
                        "Fiddler",
                        "mono Fiddler.exe",
                        github.strip(),{
                            "Fiddler on Kali Linux":"https://techstarspace.engineer/2019/04/19/fiddler-on-kali-linux/",
                            "Fiddler In Action - Part 1":"https://www.mehdi-khalili.com/fiddler-in-action/part-1",
                            "Welcome to Fiddler Everywhere!":"https://docs.telerik.com/fiddler-everywhere/introduction",
                            
                        },
                       
                        method="github",
                        github_install="apt-get install mono-complete -y && wget http://telerik-fiddler.s3.amazonaws.com/fiddler/fiddler-linux.zip && unzip fiddler-linux.zip -d fiddler && rm -rf fiddler-linux.zip && cd fiddler",
                        github_check="fiddler",
                    )

def ptf():
    github = "The PenTesters Framework (PTF) is a Python script designed for Debian/Ubuntu/ArchLinux based distributions to create a similar and familiar distribution for Penetration Testing. PTF attempts to install all of your penetration testing tools (latest and greatest), compile them, build them, and make it so that you can install/update your distribution on any machine. Everything is organized in a fashion that is cohesive to the Penetration Testing Execution Standard (PTES) and eliminates a lot of things that are hardly used"
    template.template(
                        "PTF",
                        "./ptf",
                        github.strip(),
                       {
                           "The Penetration Testers Framework (PTF) - Is a Way for Modular Support for Up-to-date Tools ":"https://www.kitploit.com/2015/05/the-penetration-testers-framework-ptf.html?m=1",
                           "What is a Penetration Testing Framework?":"https://www.mitnicksecurity.com/blog/what-is-a-penetration-testing-framework",
                       },
                        method="github",
                        github_install="git clone https://github.com/trustedsec/ptf.git && cd ptf && pip install -r requirements.txt && chmod +x ptf ",
                        github_check="ptf",
                    )

if __name__ == "__main__":
    main()



import os
from cyberonix.main.tools import template, banner, colors, WEB_Application_Analysis,Configuration_Management


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Password Hacking")
        list_root_attacks = ["Useful Sites","Brute Force Attacks", "Dictionary Attacks", "Rainbow Table Attack",
                             "Wordlist Generator", "Phishing Attacks", "Keylogger Attacks", "go back"]
        for i in range(len(list_root_attacks)):
            print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Useful Websites")
            os.system("clear")
            template.template("Useful Websites", "no-tools", 'This is website for information gathering', {
                "Salted Password Hashing - Doing it Right": "https://crackstation.net/hashing-security.htm", 
                "CrackStation's Password Cracking Dictionary":"https://crackstation.net/crackstation-wordlist-password-cracking-dictionary.htm", 
                "Wordlist Download": "https://crackstation.net/crackstation-wordlist-password-cracking-dictionary.htm",
                "CyberChef - A must have security tool": "https://www.youtube.com/watch?v=rT_CjwKN380",
                "CyberChef – Data decoding made easy": "https://www.csnp.org/post/cyberchef-data-decoding-made-easy",


            })
        elif option == "2":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Brute Force")
                banner.description("A brute force attack is a method of attempting to gain unauthorized access to a computer or network by systematically trying every possible combination of charactersor words in order to discover a valid password or key. In a 'pure' brute force attack, all possible combinations are tried one after another until the correct one is found. This can be a time-consuming process, but it is often effective because many people use easily-guessed passwords.")
                list_root_attacks = ["Hashcat\t\t(Recommended)", "John The Ripper\t(Recommended)", "Hydra\t\t(Recommended)", "Dirsearch",
                                     "Johnny (GUI John)","Dirbuster", "Reaver", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(
                        f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    hashcat()
                elif ask == "2":
                    john_the_ripper()
                elif ask == "3":
                    hydra()
                elif ask == "4":
                    WEB_Application_Analysis.dirsearch()
                elif ask == "5":
                    johnny()
                elif ask == "6":
                    Configuration_Management.dirbuster()
                elif ask == "7":
                    reaver()
                else:
                    break

        elif option == "3":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Dictionary Attacks")
                banner.description("A dictionary attack is a type of brute force attack that involves trying every word in a predefined list (a dictionary) as a password. This method is more efficient than a traditional brute force attack, where every possible combination of characters is tried, because most people use common words or phrases as passwords. The attacker can also use a list of commonly used passwords or publicly available information about the target (such as their name, birthdate, etc.) to create a custom dictionary.")
                list_root_attacks = ["Hashcat\t\t(Recommended)", "John The Ripper\t(Recommended)", "Hydra\t\t(Recommended)",
                                     "Medusa", "Ncrack", "Johnny (GUI John)", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    hashcat()
                elif ask == "2":
                    john_the_ripper()    
                elif ask == "3":
                    hydra()    
                elif ask == "4":
                    medusa()
                elif ask == "5":
                    ncrack()
                elif ask == "6":
                    johnny()
                else:
                    break
        elif option == "4":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Rainbow Table Attack")
                banner.description("A rainbow table attack is a method of cracking password hashes by using precomputed tables of hash values, which can be faster than traditional brute force attack. It is particularly effective against hash functions that are fast to compute and vulnerable to collisions, but less effective against stronger hash functions.")
                list_root_attacks = ["RainbowCrack", "ophCrack", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(
                        f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    rainbowcrack()   
                elif ask == "2":
                    ophcrack()
                else:
                    break

        elif option == "5":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Wordlist Generator")
                banner.description("A wordlist generator is a tool that generates a list of words or phrases that can be used in a dictionary attack. The list can be generated from a predefined dictionary, real-world data such as web pages, or by using a combination of commonly used words or patterns. This list of words is then used to try as potential passwords in a dictionary attack, which can be more efficient than a traditional brute force attack as it tries only words that are likely to be used as passwords.")
                list_root_attacks = ["Crunch", "Cupp", "bopscrk", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(
                        f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    crunch()
                elif ask == "2":
                    cupp()
                elif ask == "3":
                    bopscrk()
                else:
                    break

        elif option == "6":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Phishing Attacks")
                banner.description("A phishing attack is a type of cyber attack in which an attacker uses fraudulent emails, websites, or other means of communication to trick a victim into providing sensitive information such as login credentials, personal information, or financial details. The attacker often poses as a trustworthy entity and attempts to convince the victim to click on a link, download an attachment, or enter information into a fake website. The goal of a phishing attack is to steal sensitive information or install malware on the victim's device.")
                list_root_attacks = ["Social-Engineer Toolkit (SET)", "HiddenEye", "r3bu5", "zphisher\t\t(Recommended)",
                                     "Shellphish", "Gophish (GUI)\t(Recommended)", "Camphish\t\t(Recommended)", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(
                        f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    setoolkit()
                elif ask == "2":
                    hiddeneye()
                elif ask == "3":
                    r3bu5()
                elif ask == "4":
                    zphisher()
                elif ask == "5":
                    shellphish()
                elif ask == "6":
                    gophish()
                elif ask == "7":
                    camphish()
                else:
                    break

        elif option == "7":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Keylogger Attacks")
                banner.description("A keylogger attack is a type of cyber attack in which an attacker uses malicious software, called a keylogger, to record every keystroke made by a victim on their computer or mobile device. This includes passwords, credit card numbers, personal information, and other sensitive data. The keylogger can also take screenshots of the victim's screen, record their internet browsing history, and even capture audio and video. The attacker can use this information to steal personal identities, login credentials, and financial information, or to gain access to sensitive systems. Keyloggers can be installed through malware, email attachments,or social engineering tactics like phishing.")
                list_root_attacks = ["Keylogger", "go back"]
                for i in range(len(list_root_attacks)):
                    print(colors.options, f"{i+1}) {list_root_attacks[i]}".title(), colors.reset)
                try:
                    ask = input(
                        f"\n {colors.select}Select An Option ->{colors.reset}  ")
                except KeyboardInterrupt:
                    return
                if ask == "1":
                    keylogger()    
                else:
                    break
        else:
            return
        


def medusa():
    github = "Medusa is a password cracking tool that is used to perform brute-force attacks on login credentials. It is a command-line tool that can be used to test the security of login systems by trying a large number of possible username and password combinations. Medusa is capable of testing various protocols such as HTTP, HTTPS, FTP, SSH, and more. It is mainly used by penetration testers and security professionals to identify weak passwords in a network and help improve the overall security of an organization. However, like other password cracking tools, it can also be used by malicious actors for illegal activities."
    template.template("medusa", "medusa", github.strip(), {"A Detailed Guide on Medusa": "https://www.hackingarticles.in/a-detailed-guide-on-medusa/",
                                      "Bruteforce Password Cracking with Medusa": "https://www.yeahhub.com/bruteforce-password-cracking-medusa-kali-linux/"})
                
def ncrack():
    github = "Ncrack is a network authentication cracking tool. It is designed to perform efficient brute-force and dictionary attacks against a variety of different network protocols, including Telnet, FTP, HTTP, HTTPS, SMB, and RDP. It can be used to test the security of networks and remote systems by attempting to log in with a large number of different username and password combinations.Ncrack is similar to other password cracking tools such as John the Ripper and Hydra, but it is specifically designed to work with network protocols. It can run on Windows, Linux, and macOS and is often used by security professionals and penetration testers to test the security of networks and web applications"
    template.template("ncrack", "ncrack", github.strip(), {"Comprehensive Guide on Ncrack – A Brute Forcing Tool": "https://www.hackingarticles.in/comprehensive-guide-on-ncrack-a-brute-forcing-tool/",
                                      "Ncrack – Network Authentication and Password Cracking Tool": "https://secnhack.in/ncrack-network-authentication-and-password-cracking-tool/"})
               
def reaver():
    github = "Reaver implements a brute force attack against Wifi Protected Setup (WPS) registrar PINs in order to recover WPA/WPA2 passphrases, as described in Brute forcing Wi-Fi Protected Setup When poor design meets poor implementation. by Stefan Viehböck. Reaver has been designed to be a robust and practical attack against Wi-Fi Protected Setup (WPS) registrar PINs in order to recover WPA/WPA2 passphrases and has been tested against a wide variety of access points and WPS implementations."
    template.template("reaver", "reaver", github.strip(), {
                                      "Revear cheatsheet": "https://cheatography.com/jlunz/cheat-sheets/reaver-cheat-sheet/", "Revear github": "https://github.com/t6x/reaver-wps-fork-t6x/blob/master/README.md", })
                
def johnny():
    github = "Johnny is a GUI (Graphical User Interface) for the John the Ripper password cracking tool. It provides a user-friendly interface for managing and running John the Ripper's cracking tasks, rather than using command line commands. It is designed to make the process of cracking passwords more efficient and user-friendly. It can run on Windows, Linux and MacOS."
    template.template("johnny", "johnny", github.strip(), {
                                      "How to use the Johnny GUI for password cracking": "https://andregodinho1.medium.com/how-to-use-johnny-an-advanced-password-cracker-recovery-gui-soft-61736c8cb1ca", "Password cracking with Johnny": "https://www.youtube.com/watch?v=Wrg6XZu6Luw"})
                
def hydra():
    github = "Hydra is a password cracking tool that performs brute-force and dictionary attacks on network protocols such as Telnet, FTP, HTTP, and SSH. It is used to test the security of remote systems by attempting to log in with multiple username and password combinations. It can run on multiple operating systems and is commonly used by security professionals and penetration testers."
    template.template("hydra", "hydra", github.strip(), {"How to use the hydra for password cracking": "https://www.techtarget.com/searchsecurity/tutorial/How-to-use-the-Hydra-password-cracking-tool",
                                      "Hydra Tool For Brute- force attack": "https://systemweakness.com/hydra-tool-for-brute-force-attack-72653db7abe9?gi=efe05fea34af"})
                
def john_the_ripper():
    github = "John the Ripper is a free and open-source password cracking software tool. It can be run on a variety of operating systems, including Windows, macOS, and Linux. It uses a combination of wordlists and rules to try and guess the password for a given hash or file, and can support a variety of different hash types, including those used for Unix and Windows passwords. John the Ripper is commonly used by security professionals and system administrators to audit the security of their systems and detect weak or easily guessable passwords."
    template.template("john", "john -h", github.strip(), {"How to Crack Passwords using John The Ripper – Pentesting Tutorial": "https://www.freecodecamp.org/news/crack-passwords-using-john-the-ripper-pentesting-tutorial/", "How to use the John the Ripper password cracker": "https://www.techtarget.com/searchsecurity/tutorial/How-to-use-the-John-the-Ripper-password-cracker", "Unveiling the Power of John the Ripper: A Beginner’s Guide to Password Cracking":
                                      "https://infosecwriteups.com/unveiling-the-power-of-john-the-ripper-a-beginners-guide-to-password-cracking-a9846172b35a", "Open-wall John": "https://www.openwall.com/john/", "Password Cracking With John The Ripper": "https://medium.com/@mohitdeswal_35470/john-the-ripper-a-comprehensive-guide-to-password-cracking-9335f44ed3f5", "Tips and Tutorials of John": "https://www.varonis.com/blog/john-the-ripper"})
                
def hashcat():
    github = "Hashcat is an open-source password cracking tool that can perform dictionary, brute force and combination attacks, it uses the power of GPUs to accelerate the cracking process, supports a wide variety of hashing algorithms and it can run on Windows, Linux and macOS. It's widely used for password recovery, security testing and penetration testing."
    template.template("hashcat", "hashcat -h", github.strip(), {"Hashcat tutorial for beginners": "https://resources.infosecinstitute.com/topic/hashcat-tutorial-beginners/",
                                      "How to Crack Passwords Using Hashcat Tool?": "https://geekflare.com/password-cracking-with-hashcat/"})
                
def rainbowcrack():
    github = "RainbowCrack is a password cracking tool that uses a large precomputed table of hash values to speed up the process of cracking passwords. It is commonly used to crack Windows LM hashes and NTLM hashes, as well as other types of hashes such as those used in Linux and Unix-based systems. The tool is named after the 'rainbow table' data structure it uses to efficiently store the precomputed hash values."
    template.template("rainbowcrack", "rcrack", github.strip(), {"How to use rainbow-crack tool": "https://null-byte.wonderhowto.com/how-to/rainbow-tables-create-use-them-crack-passwords-0131470/",
                                      "Rainbow Tables & Rainbow-crack Cracking Passwords": "https://www.kalilinux.in/2021/03/rainbow-tables-rainbowcrack-kali-linux.html"})

def ophcrack():
    github = "Ophcrack is a free, open-source password cracking tool specifically designed to crack Windows login passwords. It uses rainbow tables, a precomputed table of hash values, to crack passwords quickly. It can also recover LM and NTLM hashes, and it supports a variety of hash algorithms such as LM, NTLM, and MD5. The tool is available as a bootable CD or USB drive and can be used to recover lost or forgotten Windows passwords."
    template.template("ophcrack", "ophcrack", github.strip(), {
                                      "Crack Windows Passwords With Ophcrack and Rainbow Tables": "https://www.wikihow.com/Crack-Windows-Passwords-With-Ophcrack-and-Rainbow-Tables/"})
                
def crunch():
    github = "Crunch is a wordlist generator tool that can be used to generate a list of all possible combinations of characters for a given set of parameters. It can be used to generate a wordlist for password cracking, testing password policies and other security related tasks. It is a simple command line tool that can be used to generate wordlists with different character sets, lengths, patterns and other parameters. It can also use a standard or a custom character set to generate the wordlist and can be used to generate a wordlist of any size."
    template.template("crunch", "crunch", github.strip(), {"Create Wordlist Using Crunch": "https://null-byte.wonderhowto.com/how-to/tutorial-create-wordlists-with-crunch-0165931/",
                                      "Crunch Password List Generation": "https://www.hackingtutorials.org/general-tutorials/crunch-password-list-generation/", "Complete Guide on Crunch Tool": "https://secnhack.in/complete-guide-on-crunch-tool/"})
                
def cupp():
    github = "CUPP (Common User Passwords Profiler) is a tool that generates a custom wordlist based on personal information about a target. It can be used to generate a wordlist based on information such as the target's name, birthdate, address, and other personal details. CUPP can be used to perform a dictionary attack on a password hash, trying all the generated words as passwords, in order to crack the password. CUPP is written in Python and it's open source."
    template.template("cupp", "cupp", github.strip(), {"Cybrary CUPP Tool": "https://www.cybrary.it/blog/0p3n/using-cupp-tool-generate-powerful-password-lists/", "How To Create Password List Using CUPP Tool":
                                      "https://programmercave0.github.io/blog/2019/10/10/How-to-create-Password-list-using-CUPP-tool-on-ubuntu", "CUPP Tool Password Generator)": "https://www.geeksforgeeks.org/cupp-common-user-passwords-profiler/"})
                
def bopscrk():
        github = "Bopscrk (Before Outset Password Cracking) is a tool to generate smart and powerful wordlists for targeted attacks. It is part of Black Arch Linux for as long as we can remember. It introduces personal information related to the target and combines every word and transforms it into possible passwords. It also contains a lyric pass module which allows it to search lyrics related to the favourite artist of the target and then include them into the wordlists."
        template.template("bopscrk", "bopscrk -i", github.strip(), {"Create Wordlist Like Pro by Zsecurity": "https://zsecurity.org/create-password-wordlists-like-a-pro-2/",
                                      "Wordlist For Pentester": "https://www.hackingarticles.in/wordlists-for-pentester/"}, method="pip")
                

def setoolkit():
    github = "The Social Engineering Toolkit (SET) is an open-source penetration testing framework that is used to perform various social engineering attacks. It is designed to be used for the purposes of penetration testing and vulnerability assessments, and it can be used to perform attacks such as phishing, website attacks, and other forms of social engineering. The toolkit is written in Python and is available for Windows, Linux, and Mac OS X. It can be used to test the security of an organization's employees and to evaluate the effectiveness of security awareness training programs."
    template.template("set", "setoolkit", github.strip(), {"Phishing using SET": "https://www.golinuxcloud.com/social-engineering-toolkit-phishing/",
                                      "Phishing using SET by Hengky Sanjaya": "https://medium.com/hengky-sanjaya-blog/social-engineering-toolkit-set-23be8b66aa18"})


def hiddeneye():
    github = "HiddenEye is a modern phishing tool with advanced functionality. It is written in Python and can be run on Windows, Linux, and Mac OS X. It allows you to perform various phishing attacks."
    template.template("HiddenEye", "python HiddenEye.py", github.strip(), {"HiddenEye by GeeksForGeeks": "https://www.geeksforgeeks.org/hiddeneye-modern-phishing-tool-with-advanced-functionality/", "HiddenEye by Zsecurity": "https://zsecurity.org/hiddeneye-with-ngrok-all-in-one-phishing-solution/",
                                      "HiddenEye by Null-Byte": "https://null-byte.wonderhowto.com/forum/phish-with-hiddeneye-tool-with-advanced-feature-0323221/"}, method="github", github_install="git clone https://github.com/Morsmalleo/HiddenEye && cd HiddenEye && pip install -r requirements.txt && pip install pyngrok", github_check="HiddenEye")
def r3bu5():
    github = "It is a Phishing tool that has latest and updated login pages, Mask URL support, Beginners Friendly, Multiple tunneling options"
    template.template("r3bu5", "./r3bu5.sh", github.strip(), {"Github Repo of r3bu5": " https://github.com/k46-db0y/r3bu5"}, method="github",
                                      github_install="git clone https://github.com/k46-db0y/r3bu5.git && cd r3bu5 && chmod +x r3bu5.sh", github_check="r3bu5")
        
def zphisher():
    github = "Zphisher is an open-source phishing tool that automates the process of creating and deploying phishing pages. It allows users to easily create phishing pages for various popular websites, such as Google, Facebook, and LinkedIn, and can be used to perform phishing attacks on targeted individuals or organizations. It can also be used to test the security awareness of an organization's employees. Zphisher is written in Shell Script and it's available for Linux and Termux."
    template.template("zphisher", "bash zphisher.sh", github.strip(), {"Zphisher – Automated Phishing Tool in Kali Linux": "https://www.geeksforgeeks.org/zphisher-automated-phishing-tool-in-kali-linux/",
                                      "Creating Phishing Links with Zphisher": "https://medium.com/@jbtechmaven/creating-phishing-links-with-zphisher-db7cc8a1f013"}, method="github", github_install="git clone git://github.com/htr-tech/zphisher.git && cd zphisher && chmod +x zphisher.sh", github_check="zphisher")        
def gophish():
    github = "Gophish is an open-source tool for conducting phishing campaigns. It allows users to create, send and track phishing campaigns, including the ability to create custom phishing templates and landing pages, as well as track user interactions with the phishing emails. Gophish is often used by penetration testers and security professionals to test the security of an organization's email system and educate employees on how to spot and avoid phishing attempts. However, like other phishing tools, it can also be used by malicious actors for illegal activities."
    template.template("Gophish", "gophish]", github.strip(), {"Create phishing campaign gophish": "https://www.golinuxcloud.com/create-phishing-campaign-gophish/", "Phishing attack using gophish": "https://www.techrepublic.com/article/how-to-run-a-phishing-attack-simulation-with-gophish/"},
                                      method="github", github_install="git clone https://github.com/gophish/gophish.git && cd gophish && chmod +x gophish.go && go run gophish.go", github_check="Gophish")
def shellphish():
    github = "Shellphish is a tool used for phishing attacks, specifically for the purpose of stealing login credentials. It automates the process of creating phishing pages for various websites, such as social media platforms and email services. The tool is typically used by ethical hackers and penetration testers to test the security of a system, but can also be used by malicious actors for illegal activities."    
    template.template("ShellPhish", "./shellphish.sh", github.strip(), {"Shellphish Tool": "https://www.kalilinux.in/2019/04/shellphish-phishing-page-creator.html"},
                                      method="github", github_install="git clone https://github.com/AbirHasan2005/ShellPhish && cd ShellPhish && chmod +x shellphish.sh", github_check="ShellPhish")


def keylogger():
    github = "Welcome to the simple keylogger repo! A keylogger is a program that records your keystrokes, and this program saves them in a log file on your local computer."
    template.template("Keylogger", "python Keylogger.py", github.strip(), {
                                      "How to Set Up Keylogging on Your Linux Computer": "https://www.makeuseof.com/set-up-keylogging-on-linux/"}, method="github",github_install="git clone https://github.com/GiacomoLaw/Keylogger.git && cd Keylogger/linux && pip install -r requirements.txt ", github_check="Keylogger")

def camphish():
    github = "CamPhish is techniques to take cam shots of target's phone front camera or PC webcam. CamPhish Hosts a fake website on in built PHP server and uses ngrok & serveo to generate a link which we will forward to the target, which can be used on over internet. website asks for camera permission and if the target allows it, this tool grab camshots of target's device."
    template.template("CamPhish", "camphish", github.strip(), {"How To Access Android Phone Camera Using Kali Linux": "https://blog.hackerassociate.com/how-to-access-android-phone-camera-using-kali-linux/", "Hack Android Phone Camera using CamPhish":
                                      "https://systemweakness.com/hack-android-phone-camera-using-camphish-9d6126ae7786"}, method="github", github_install="git clone https://github.com/techchipnet/CamPhish && cd CamPhish && bash camphish.sh", github_check="camphish")


if __name__ == "__main__":
    main()
